#
# spec file for package librsvg
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Don't forget to update this in baselibs.conf too!
%define librsvg_sover 2

Name:           librsvg
Version:        2.59.2
Release:        2.3
Summary:        A Library for Rendering SVG Data
License:        LGPL-2.1-or-later AND MIT
Group:          Development/Libraries/C and C++
URL:            https://wiki.gnome.org/Projects/LibRsvg
Source0:        %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst
Source99:       baselibs.conf

BuildRequires:  cargo-c
BuildRequires:  cargo-packaging >= 1.2.0+3
BuildRequires:  gobject-introspection-devel
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  python3-docutils
BuildRequires:  vala
BuildRequires:  pkgconfig(cairo) >= 1.18.0
BuildRequires:  pkgconfig(cairo-png) >= 1.2.0
BuildRequires:  pkgconfig(dav1d)
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(freetype2) >= 20.0.14
BuildRequires:  pkgconfig(gdk-pixbuf-2.0) >= 2.20
BuildRequires:  pkgconfig(gi-docgen)
BuildRequires:  pkgconfig(gio-2.0) >= 2.24.0
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(glib-2.0) >= 2.50.0
BuildRequires:  pkgconfig(gmodule-2.0)
BuildRequires:  pkgconfig(gthread-2.0) >= 2.12.0
BuildRequires:  pkgconfig(libxml-2.0) >= 2.9.0
BuildRequires:  pkgconfig(pangocairo) >= 1.46.0
BuildRequires:  pkgconfig(pangoft2) >= 1.46.0
# Avoid cycle: we do not require the adwaita-icon-theme to be present. libgtk-3.0 requires this for end users
#!BuildIgnore:  adwaita-icon-theme

%description
This package contains a library to render SVG (scalable vector
graphics) data. This format has been specified by the W3C (see
http://www.w3c.org).

%package -n librsvg-2-%{librsvg_sover}
Summary:        A Library for Rendering SVG Data
License:        Apache-2.0 AND LGPL-2.0-or-later AND MIT
Group:          System/Libraries
Provides:       librsvg2 = %{version}
Obsoletes:      librsvg2 < %{version}
Provides:       librsvg = %{version}
Obsoletes:      librsvg < %{version}
Obsoletes:      rsvg-view <= %{version}

%description -n librsvg-2-%{librsvg_sover}
This package contains a library to render SVG (scalable vector
graphics) data. This format has been specified by the W3C (see
http://www.w3c.org).

%package -n typelib-1_0-Rsvg-2_0
Summary:        Introspection bindings for librsvg, a SVG render library
License:        LGPL-2.0-or-later
Group:          System/Libraries

%description -n typelib-1_0-Rsvg-2_0
This package contains a library to render SVG (scalable vector
graphics) data. This format has been specified by the W3C (see
http://www.w3c.org).

This package provides the GObject Introspection bindings for librsvg.

%package devel
Summary:        Development files for librsvg, a SVG render library
License:        LGPL-2.0-or-later
Group:          Development/Libraries/C and C++
Requires:       librsvg-2-%{librsvg_sover} = %{version}
Requires:       typelib-1_0-Rsvg-2_0 = %{version}
Provides:       librsvg2-devel = %{version}
Obsoletes:      librsvg2-devel < %{version}

%description devel
This package contains all necessary include files and libraries needed
to develop applications that require these.

%package -n gdk-pixbuf-loader-rsvg
Summary:        A gdk-pixbuf loader for SVG using librsvg
License:        LGPL-2.0-or-later
Group:          System/Libraries
Supplements:    (librsvg-2-%{librsvg_sover} and gdk-pixbuf)
%{gdk_pixbuf_loader_requires}

%description -n gdk-pixbuf-loader-rsvg
This package contains a library to render SVG (scalable vector
graphics) data. This format has been specified by the W3C (see
http://www.w3c.org).

This package provides a librsvg-based gdk-pixbuf loader.

%package -n rsvg-convert
Summary:        SVG Convert using the GNOME Render SVG library
License:        LGPL-2.0-or-later
Group:          Productivity/Graphics/Viewers
Conflicts:      rsvg-view <= 2.45.7

%description -n rsvg-convert
This package contains a tool to convert SVG (scalable vector
graphics) data. This format has been specified by the W3C (see
http://www.w3c.org).

%package -n rsvg-thumbnailer
Summary:        SVG thumbnailer using the GNOME Render SVG library
License:        LGPL-2.0-or-later
Group:          Productivity/Graphics/Other
BuildArch:      noarch

%description -n rsvg-thumbnailer
This package contains a thumbnailer to render SVG (scalable vector
graphics) data.

%prep
%autosetup -p1 -a1

%build
%meson
%meson_build

%install
%meson_install

%check
export LANG=C
%ifarch x86_64 %{?x86_64}
# 2023-01-15: the pdf-related tests are failing (bsc#1207167)
# 2023-03-17 cairo-1.17.8 filter_morphology svg test is failing
%{cargo_test} -- \
--skip pdf_has_text --skip pdf_has_link \
--skip filter_morphology_from_reference_page_svg --skip bugs_bug668_small_caps_svg
%endif

%ldconfig_scriptlets -n librsvg-2-%{librsvg_sover}

%post -n gdk-pixbuf-loader-rsvg
%{gdk_pixbuf_loader_post}

%postun -n gdk-pixbuf-loader-rsvg
%{gdk_pixbuf_loader_postun}

%files -n librsvg-2-%{librsvg_sover}
%license COPYING.LIB
%doc NEWS README.md
%{_libdir}/librsvg-2.so.*

%files -n typelib-1_0-Rsvg-2_0
%{_libdir}/girepository-1.0/Rsvg-2.0.typelib

%files -n gdk-pixbuf-loader-rsvg
%{_libdir}/gdk-pixbuf-2.0/*/loaders/libpixbufloader_svg.so

%files -n rsvg-convert
%{_bindir}/rsvg-convert
%{_mandir}/man1/rsvg-convert.1%{?ext_man}

%files -n rsvg-thumbnailer
%dir %{_datadir}/thumbnailers
%{_datadir}/thumbnailers/librsvg.thumbnailer

%files devel
%doc AUTHORS
%doc %{_datadir}/doc/Rsvg-2.0/
%{_includedir}/librsvg-2.0/
%{_libdir}/librsvg-2.so
%{_libdir}/pkgconfig/librsvg-2.0.pc
%{_datadir}/gir-1.0/Rsvg-2.0.gir
%dir %{_datadir}/vala/vapi
%{_datadir}/vala/vapi/librsvg-2.0.vapi
%{_datadir}/vala/vapi/librsvg-2.0.deps

%changelog
* Thu Oct 31 2024 Michael Gorse <mgorse@suse.com>
- Change license to LGPL-2.1-or-later AND MIT.
* Wed Oct 30 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 2.59.2:
  + Fix stack overflow due to unbounded recursion.  Now there is
    a hard limit on the number of nested layers that an SVG
    document may have.  This is not a hard limit on the amount of
    stack space consumed, but it is a general mitigation.
  + Fix regression when rendering paths with very flat elliptical
    arcs.  This bug was introduced in 2.59.1 as part of the
    mitigation for paths with coordinates that Cairo is unable to
    handle.
  + Fix centering and text-anchor in general for scaled text.
  + Fix building with Rust 1.82 on Windows (Christoph Reiter).
  + Make cancellation work for all the resource loading
    functions.
  + Add documentation for rsvg-bench to the development guide.
  + Slight improvement in memory consumption for language tags.
  + Many updates to the developer's documentation, for Outreachy
    interns.
* Sat Sep 28 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.59.1:
  + Two mitigations for crashes found throuh fuzz testing:
  - Cairo is easy to crash by giving it path coordinates that are
    outside of the range that it can represent internally with
    its fixed-point arithmetic. Fuzzers usually produce SVGs with
    very large numbers for coordinates, which overflow Cairo's
    arithmetic.
    This is just a *mitigation*, not a complete fix: librsvg will
    now check if path coordinates are outside of Cairo's
    supported range, and it will not render shapes with
    problematic coordinates. However, fuzzers may still produce
    coordinates that are in range but that still make Cairo
    crash. I am starting to learn Cairo's code to see if this can
    be fixed gradually.
* Mon Sep 16 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.59.0:
  + The biggest change in this release is that librsvg now uses the
    Meson build system instead of autotools.
  + With Meson, librsvg now builds a lot more reliably on Windows
    and MacOS.
  + Librsvg now uses Meson instead of Autotools
  + There is a -Davif meson option to include support for AVIF in
    the image-rs crate, which librsvg uses to load raster images.
  + Librsvg now explicitly builds only its supported raster formats
    for image-rs: JPEG, PNG, GIF, WEBP, and optional compile-time
    support for AVIF). Other raster image formats are not
    supported, to minimize the attack surface.
  + Librsvg now supports cancellable rendering; you can start
    rendering an RsvgHandle in one thread, and stop it from another
    thread with a GCancellable. In the C API, you can use the
    rsvg_handle_set_cancellable_for_rendering() function; in the
    Rust API, CairoRenderer now has a with_cancellable() method.
  + For Rust users, there is now a 'librsvg-rebind' crate that
    binds the C API for use from Rust. Internally this links to the
    system's librsvg shared library, in contrast with the 'librsvg'
    crate, which is statically linked and which has a native Rust
    API. The 'librsvg-rebind' crate is for cases where the
    additional code size from static linking is not desired. This
    librsvg-rebind crate is available from crates.io.
  + A bunch of fixes to bugs found through fuzz testing.
- Use ldconfig_scriptlets macro for some of the post(un) handling.
* Sun Sep 15 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.58.94:
  + The minimum supported Rust version (MSRV) is 1.77.2.
  + Fix assertion failures with large Hue value in hsl() or hwb()
    colors.
  + Limit the baseFrequency for feTurbulence to avoid integer
    overflow.
  + Only make exported symbols visible in the library's binary.
  + Fix the -Davif=enabled feature; it was not being handled
    correctly at compilation time.
  + Ensure compatibility with Binutils < 2.39.
  + Build fixes for Windows.
* Sat Sep 14 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.58.92:
  + Librsvg is now part of Google's oss-fuzz and is fuzz-tested
    automatically - see
    https://gnome.pages.gitlab.gnome.org/librsvg/devel-docs/oss_fuzz.html
    for details.
  + This release has two bug fixes from fuzz testing, and a new API
    call:
  - Don't leak XML entities when the XML document fails to parse.
  - Fix stack overflow in <use> reference cycle.
  - Librsvg now supports cancellable rendering; you can start
    rendering an RsvgHandle in one thread, and stop it from
    another thread with a GCancellable. In the C API, you can use
    the rsvg_handle_set_cancellable_for_rendering() function; in
    the Rust API, CairoRenderer now has a with_cancellable()
    method.
  + Many build fixes for Windows, MacOS, iOS, and cross-compilation
  + Continued refactoring for a render tree.
  + Many fixes to the documentation.
* Fri Sep 13 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 2.58.91:
  + Librsvg now requires cairo version 1.18.0 or later.
  + Librsvg now explicitly builds only its supported raster
    formats for image-rs: JPEG, PNG, GIF, WEBP, and optional
    compile-time support for AVIF. Other raster image formats are
    not supported, to minimize the attack surface.
  + Don't generate gdk-pixbuf loaders cache if DESTDIR is set.
  + Documentation updates for meson.
  + Document the fact that the default DPI in the C API for
    RsvgHandle is 90 DPI, unlike rsvg-convert and the Rust API,
    which use 96 DPI.
  + Document the security considerations for the image-rs crate
    and the raster image formats that librsvg supports.
  + Fix and fine-tune compilation on Windows (MSVC and msys2),
    MacOS, and Android.
  + Fix installation when only compiling the static library.
  + Update Pango for CI and fix a test file. The test suite now
    includes the DejaVu Sans font, which supports extra
    glyphs/languages for the test suite.
- Changesfrom version 2.58.90:
  + librsvg has been ported to the Meson build system.  Librsvg no
    longer uses autotools!
  + Changes in this release:
  - Librsvg now uses Meson instead of Autotools.
  - There is a -Davif meson option to include support for AVIF in
    the image-rs crate, which librsvg uses to load raster images.
  - Start revamping the fuzzing infrastructure.
- Add cargo-c and pkgconfig(dav1d) BuildRequires: new dependencies.
* Thu Sep 12 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.58.4:
  + Fix regression when using an SVG inside a feImage element.
* Fri Aug 16 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.58.3:
  + A couple of fixes from fuzz testing:
  - Fix assertion failures with large Hue value in hsl() or hwb()
    colors.
  - Limit the baseFrequency for feTurbulence to avoid integer
    overflow.
  - Remove an obsolete test.
* Fri Jul 12 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.58.2:
  + Don't leak XML entities when the XML document fails to parse.
  + Fix stack overflow in <use> reference cycle.
* Mon May 27 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 2.58.1:
  + Fix failing test with Pango 1.52.1.
* Mon Mar 18 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 2.58.0:
  + The most significant change in this release is that librsvg no
    longer uses gdk-pixbuf for loading raster images. All image
    loading uses Rust codecs now.
  + Librsvg's gdk-pixbuf loader for SVG documents is unchanged; you
    can still load SVG files from gdk-pixbuf with it as usual.
  + Add basic support for "ch" length units in CSS.
  + Support "var(--foo, #aabbcc)" just for colors. This is the
    minimum required to render color SVG emoji fonts that provide
    color fallbacks, but it is not yet full support for CSS var().
  + Limit numOctaves in feTurbulence to avoid unbounded CPU
    consumption.
  + Don't panic when a :lang selector has an argument that is not a
    language-range.
* Sat Mar  9 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 2.57.92:
  + Don't panic when rendering feOffset with a too-large offset.
  + Don't panic when a decoded image has dimensions of zero.
* Wed Mar  6 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 2.57.91:
  + Rsvg-convert now prints a helpful message if you run it
    without arguments, to indicate that it is reading from standard
    input.
  + Take text orientation into account for 'ch' units
  + For Rust programs, the rsvg crate no longer depends on
    gdk-pixbuf. Hopefully this means that your Rust programs will
    have to link to one fewer library.
  + The C enumeration RsvgUnit now has a RSVG_UNIT_CH variant for
    "ch" units. However, this is only used for reporting the size
    of SVG documents, which should very seldom come in "ch" units.
  + Fix unsoundness in the use of the selectors crate.
  + Update gtk-rs crates.
* Thu Jan  4 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 2.57.1:
  + Fix small-caps and bump the version of Pango required to 1.50.0.
  + Fix panic when using negative scaling transforms on the
    toplevel.
  + Support "var(--foo, #aabbcc)" just for colors.  This is the
    minimum required to render color SVG emoji fonts that provide
    color fallbacks, but it is not yet full support for CSS var().
  + Fix the VS2017 build.
  + Update cairo-rs.
  + Update the project metadata files.
* Thu Nov 30 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Run service with new obs-service-cargo, drop cargo_config as
  source and clean up spec and service, and switch to zst as
  buildtime compression.
* Thu Sep 14 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.57.0:
  + rsvg-convert can now output PDF versions 1.4, 1.5, 1.6, in
    addition to the default 1.7, especially for LaTeX users. See
    the rsvg-convert(1) man page for options like --format=pdf1.4
  + Support the image-rendering property.
  + For consistency with other command-line tools, rsvg-convert now
    supports an argument "-" to specify the standard input. This is
    in addition to the already-supported syntax of not specifying
    an input file at all.
  + Partial support for the edgeMode attribute in feGaussianBlur,
    only for small blurs right now.
  + The minimum supported Rust version (MSRV) is 1.70.0.
* Tue Sep 12 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Skip bugs_bug668_small_caps_svg test, started failing with
  harfbuzz-8.2.0
* Tue Aug 15 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.56.92:
  + Fix the build for aarch64.
  + More extensive logging for filter primitives.
  + Update gtk-rs-core to 0.18.
  + Update dependencies.
  + Include license text in packaged crates.
  + The minimum supported Rust version (MSRV) is 1.70.0, due to the
    gtk-rs-core update.
* Fri Jul 21 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.56.3:
  + This is a security release for bug glgo#GNOME/librsvg#996.
  - glgo#GNOME/librsvg#996: Fix arbitrary file read when href has
    special characters.
  - glgo#GNOME/librsvg#998: Fix cascade for symbol elements being
    referenced from use elements.
* Wed Jun 21 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%build_rustflags instead of the deprecated
  %%__default_rustflags macro. Requires at least cargo-packaging
  1.2.0+3 (boo#1212333).
* Wed Jun 14 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%__default_rustflags instead of the deprecated %%__rustflags
  macro. Requires at least cargo-packaging 1.2.0+2 (boo#1212333).
* Wed May 31 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.56.1:
  + The minimum supported Rust version (MSRV) is 1.65.
    Unfortunately the assert_cmd crate, used in the test suite,
    bumped its MSRV and is forcing us to do the same.
  + Shrink the shared library by telling the linker to omit unused
    code.
  + Updates to dependencies.
* Fri May  5 2023 Frederic Crozat <fcrozat@suse.com>
- Tune _constraints for the various architectures.
* Thu Apr 27 2023 Frederic Crozat <fcrozat@suse.com>
- Update licence tag, there is no longer any Apache licensed code.
* Sat Apr 15 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Use __rustflags macro and drop no longer needed rustflags global.
* Fri Mar 17 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.56.0:
  + Fix crash when XML files get recursively included through
    XInclude.
  + When running the suite of reference tests, you can now use the
    TESTS_OUTPUT_DIR environment variable to specify where results
    for failures get written. See tests/README.md for details.
  + The minimum supported Rust version (MSRV) is 1.64.
* Fri Mar 17 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Pass --skip filter_morphology_from_reference_page_svg to
  cargo_test, filter out new test that fails when building against
  cairo-1.17.8.
* Thu Mar  9 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.55.92:
  + Update to cssparser 0.29.6; this adds support for hwb() color
    syntax, from the CSS Color Module Level 4 spec
    (https://drafts.csswg.org/css-color-4/#changes). Note that
    values inside hwb() are *not* comma-separated, just whitespace.
  + Fix panic when a requested font-size is too big.
  + Validate all clipPath and mask transforms.
  + Add a performance tracking framework. This is part of an
    Outreachy internship.
  + Slight improvements in the size of generated code and memory
    consumption.
  + The Rust crate is now called "rsvg", for consistency with other
    crates that don't usually have a "lib" prefix.
  + The Rust API documentation is now available at
    https://gnome.pages.gitlab.gnome.org/librsvg/doc/rsvg/index.html
- Add minimum harddisk size of 9G for x86_64 to constraints. The
  cargo test uses a lot of disk space.
* Tue Feb 28 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.55.91:
  + Support "turn" unit for CSS <angle> values.
  + Support the feDropShadow element.
  + Fix panic when a feTile filter gets an empty source region.
  + Update to gtk-rs 0.17.0.
  + Simplify the NMake Makefiles for Windows; see
    win32/MSVC-Builds.md for details.
  + Documentation and infrastructure updates.
  + Consolidate the scattered .md documents into the Development
    Guide. Updated links throughout.
    https://gnome.pages.gitlab.gnome.org/librsvg/devel-docs/index.html
  + Internal refactoring of the test suite.
  + Updated dependencies to avoid duplicated crates.
- Changes from version 2.55.90:
  + rsvg-convert now supports Tab completion for bash, elvish,
    fish, powershell, and zsh.  Please run rsvg-convert
  - -completion bash to generate the completion file.  You can use
    the other shells' names as an argument to the --completion
    option.
  + Support vector-effect="non-scaling-stroke" for paths.
  + Apply width, height when <use>ing an <svg>.
  + There is a new development guide for librsvg, for people who
    want to help in its development. I hope this will be especially
    useful to Outreachy and Summer of Code interns:
    https://gnome.pages.gitlab.gnome.org/librsvg/devel-docs/index.html
  + In the use element, honor the overflow:hidden property of a
    referenced symbol.
  + Treat property and attribute parse errors / invalid values as
    if they were not present, per the specs.  Previously this would
    cause the offending element's subtree to not be rendered.
  + Make feGaussianBlur work as a pass-through filter if the
    stdDeviation is invalid.
  + Define missing crate metadata for Cargo.toml.
  + Add some tests that were missing for the C API.
  + Fix the basic test suite in Windows.
  + Miscellaneous fixes for the build and CI.
  + Plenty of internal refactoring to enable more consistent
    logging.
  + Slight reductions in memory consumption for elements with
    context-stroke and context-fill.
  + Experimental gdk-pixbuf loader in Rust. This is not installed
    yet.
  + Update the gtk-rs crates to 0.16.0.
  + Port rsvg-convert's argument parsing to the clap4 crate.
  + Updates to the dependencies.
  + The CI now has a cargo-deny step, which should help us notice
    when there are security advisories for dependencies
* Thu Jan 12 2023 Dirk Müller <dmueller@suse.com>
- update vendor tarball
- actually run the testsuite for x86_64 (bsc#1207167)
* Tue Sep  6 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.55.1:
  + As an experiment, I'll move librsvg from even-odd versioning
    (odd minor version is unstable, even minor version is stable),
    to the versioning scheme that GNOME uses these days. So, 2.55.x
    is the new stable series.
  + There is a new development guide for librsvg, for people who
    want to help in its development. I hope this will be especially
    useful to Outreachy and Summer of Code interns:
    https://gnome.pages.gitlab.gnome.org/librsvg/devel-docs/index.html
  + Define missing crate metadata for Cargo.toml.
  + Add some tests that were missing for the C API.
  + Fix the basic test suite in Windows.
  + Miscellaneous fixes for the build and CI.
* Mon Aug 29 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update of vendored dependencies.
* Fri Aug 26 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.55.0:
  + The Minimum Supported Rust Version (MSRV) is now Rust 1.58.
  + The release tarball no longer contains vendored Rust
    dependencies. Most distributions now have infrastructure to
    pull these themselves, so let's make the tarball smaller.
  + Accept patterns with userSpaceOnUse units for the stroke of
    axis-aligned lines.
  + Small reductions in memory consumption of the DOM tree.
  + Updates for the gtk-rs API.
* Fri Aug 26 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.54.5:
  + Accept patterns with userSpaceOnUse units for the stroke of
    axis-aligned lines.
* Fri Jul  8 2022 William Brown <william.brown@suse.com>
- Replace dependency on unmaintained rust-packaging with
  cargo-packaging (boo#1198129).
* Mon Jun 20 2022 William Brown <william.brown@suse.com>
- Automatic update of vendored dependencies
* Fri Jun 17 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.54.4:
  + Support CSS Color 4 syntax for <alpha-value>. Opacities can be
    specified as numbers or percentages now, e.g. 0.5 or 50%%.
  + Roll back minimum required version of Pango to 1.46.0.
  + Fix Windows NMake install when documentation is not built.
* Sun May 15 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.54.3:
  + Fix detection of gi-docgen.
  + Install the generated documentation in the correct place so
    that Devhelp can find it.
- Changes from version 2.54.2:
  + Fix regressions when computing element geometries.
  + Add a --disable-gtk-doc option for the configure script, so
    people can disable generating documentation for
    cross-compiling.
  + MSVC: Support generating documentation, and passing
    introspection paths.
* Mon Apr 25 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 2.54.1:
  + Fix oversight in the Minimum Supported Rust Version (MSRV):
    this release requires Rust 1.56 or later.
  + Make rst2man and gi-docgen optional.
  + Fix documentation comments.
* Fri Mar 18 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.54.0:
  + Librsvg now supports SVG2 geometry properties for these
    elements: rect, circle, ellipse, image, svg.
  + Catch circular references when rendering patterns.
  + The C API documentation now uses gi-docgen instead of gtk-doc.
    Rsvg-convert's man page is now converted to reStructuredText
    instead of troff.
  + The "Recommendations for applications" chapter in the
    documentation is much improved.
* Fri Mar 18 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.53.2:
  + Output filled text as text for PDF; fixes regression due to
    outputting all text as paths.
  + Fix taller-than-wide proportional scaling and size limiting in
    rsvg-convert.
  + Implement SVG2 geometry properties for these elements: rect,
    circle, ellipse, image, svg.
  + Fix potential unaligned accesses in surface iterators.
  + Actually use GDK_PIXBUF_MODULEDIR when calling
    gdk-pixbuf-query-loaders.
  + Add links to functions and types throughout the C API
    documentation.
* Fri Mar 18 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Switch to gitcheckout of released tag.
- Switch to rust-packaging:
  + Add rust-packaging and libtool BuildRequires.
  + Drop cargo and rust BuildRequires.
  + Pass NOCONFIGURE=1 ./autogen.sh, bootstrap build.
  + Add rust config to _service
  + Add vendor.tar.xz and cargo_config as sources + macro.
- Enable testsuite again for x86_64, as it now passes.
* Fri Mar 18 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.53.1:
  + Fix incorrect text rendering when text has different scales
    in the X/Y axes. This regressed after librsvg 2.52.5, when
    Pango had to revert its fix for the same bug. Now librsvg
    renders all text as paths, and does the scaling itself. Please
    file a bug if you have evidence that this presents a
    performance problem for you.
  + Update to the latest gtk-rs release.
* Fri Mar 18 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.53.0:
  + This is the first release in the new development series. There
    are no new features, just changes to how the documentation is
    built.
  + The man page for rsvg-convert is now generated from a
    reStructuredText document, and the C API reference is generated
    using gi-docgen.
  + Please make sure you install python3-docutils (for rst2man) and
    gi-docgen before compiling librsvg from a tarball.
- Add python3-docutils and pkgconfig(gi-docgen) BuildRequires
  following upstream changes.
* Fri Mar 18 2022 Federico Mena Quintero <federico@suse.com>
- Update to version 2.52.10:
  + Fix arbitrary file read when href has special characters.
- bsc#1213502 - CVE-2023-38633 - directory traversal in URI decoder.
* Fri Mar 18 2022 Luciano Santos <luc14n0@opensuse.org>
- Update to version 2.52.8:
  + Catch circular references when rendering patterns
    (glgo#GNOME/librsvg#721).
* Sat Mar 12 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.52.7:
  + Backport a fix for the regression that was introduced in the
    last release: Output filled text as text for PDF; fixes
    regression due to outputting all text as paths.
* Thu Feb 17 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.52.6:
  + Fix incorrect text rendering when text has different scales in
    the X/Y axes. This regressed after librsvg 2.52.5, when Pango
    had to revert its fix for the same bug. Now librsvg renders all
    text as paths, and does the scaling itself. Please file a bug
    if you have evidence that this presents a performance problem
    for you.
* Fri Dec 17 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.52.5:
  + Fix mangled output in rsvg-convert when redirecting output to
    a pipe on Windows.
  + When outputting to SVG, rsvg-convert now uses the width/height
    units specified in the command line; it always used pixels
    before.
  + Fix incorrect top/left margins for SVG/PS/EPS/PDF output.
  + Fix incorrect placement of glyphs when text has non-uniform
    scaling in the X/Y axes. This is not a librsvg bug, but is
    fixed by Pango 1.49.3 and later. Hopefully Pango 1.48.11 will
    be released soon with this fix as well. Note that this release
    of librsvg cannot increase the minimum Pango version to 1.48.11
    because it is not released yet.
  + Miscellaneous: Updated crate dependencies: assert_cmd, cast,
    clap cssparser, float-cmp, itertools, nalgebra, png, proptest,
    rctree, selectors, system-deps.
* Thu Dec  2 2021 Federico Mena Quintero <federico@suse.com>
- Remove librsvg-s390x-cairo-has-current-point.patch - it is included
  in the upstream tarball now.
* Thu Nov 18 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Disable testsuite for now, let upstream figure out the issue with
  harfbuzz 3.1.1.
* Sat Nov 13 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.52.4:
  + New features:
  - Support the isolation property from the Compositing and
    Blending Level 1 specification.
  - Support Visual Studio 2022.
  + Bug fixes:
  - The opacity and mix-blend-mode properties were not being
    applied when an element has a mask.
  - Fix panic when an empty group has a pattern fill and filters.
  - Fix the tests on Windows; the still only work when Fontconfig
    is present.
  - Work around a bug in the cairo-rs bindings in the test suite,
    that only manifests itself in s/390x due to its calling
    convention. See
    https://github.com/gtk-rs/gtk-rs-core/issues/335
* Sat Nov  6 2021 Federico Mena Quintero <federico@suse.com>
- Add librsvg-s390x-cairo-has-current-point.patch for
  https://github.com/gtk-rs/gtk-rs-core/issues/335 - otherwise the
  test suite fails on s390x due to a bug in the cairo-rs bindings.
* Tue Nov  2 2021 William Brown <william.brown@suse.com>
- Add cargo audit obs service
* Wed Oct 27 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.52.3:
  + Bugfixes, mostly for text layout. Also, text links in PDF!
  - Support text-decoration=overline.
  - Basic support for the unicode-bidi property. Librsvg still
    considers each tspan independently of others, which is
    incorrect, but at least bidi-override works now for a single
    embedding level.
  - Fix placement of tspan that changes the text direction.
  - :lang() selector should now match lang attribute from an
    element's parent.
  - Fix the text-anchor property for right-to-left text.
  - PDF now includes links inside text elements.
* Sat Oct 16 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.52.2:
  + New features:
  - rsvg-convert now supports generating multi-page PDFs in a
    sensible way.
  - With one SVG document per page, each page with the SVG's
    natural size:
  - rsvg-convert --format=pdf -o out.pdf a.svg b.svg c.svg
  - With all pages sized as portrait US Letter, and each SVG
    scaled to fit so that there is a 1in margin around each page:
    rsvg-convert --format=pdf -o out.pdf \
  - -page-width=8.5in --page-height=11in \
  - -width=6.5in --height=8.5in --keep-aspect-ratio \
  - -top=1in --left=1in a.svg b.svg c.svg
    Please see the man page for details.
  - Support <a> elements inside <text>. Also, support the CSS
    :link pseudo-class for matching against links.
  - Support the CSS :lang() pseudo-class for matching against an
    element's xml:lang attribute.
  - Support the mask-type property from SVG2.
  + Bugs fixed:
  - Don't panic when a shorthand property is set to inherit.
  - Fix regression with the viewport size of interior <svg>
    elements.
  - Allow length units to be case-insensitive, per SVG2.
  + Documentation:
  - There is now a FEATURES.md in the repository, where you can
    see all the elements, attributes, and properties that librsvg
    supports. We will be adding detail to this gradually.
  - For developers, there is now devel-docs/adding-a-property.md
    with a tutorial on how to add support for new CSS properties.
* Wed Oct  6 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.52.1:
  + Fix ordering of tspan inside text elements for right-to-left
    languages.
  + Fix text-anchor positioning for right-to-left languages.
  + Fix regression in computing sizes when an SVG has only one of
    width/height and a viewBox.
  + Spec compliance - the writing-mode property applies only to
    text elements, no to individual tspan elements.
  + Fix build on big-endian platforms.
  + Clarify documentation for the rsvg_handle_write() /
    rsvg_handle_close() deprecated APIs.
* Sun Sep 26 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Disable testsuite run on ix86 and arm.
* Fri Sep 17 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 2.52.0:
  + The biggest user-visible change is that rsvg-convert has been
    ported to Rust.
  + rsvg-convert is now aware of physical units, and fixes a bug
    where PDFs were created at the wrong size.
  + Support for Accept-Language.
  + rsvg-convert's default DPI is now 96, to better match W3C
    standards.
  + SVG2/CSS3 features:
  - Transform property from SVG2; previously librsvg only
    supported the transform attribute from SVG1.1, which has
    different syntax.
  - context-fill and context-stroke for <marker> and <use>
    elements.
  - markers now support orient="auto-start-reverse".
  - paint-order for text elements.
  - "auto" values for the width and height attributes of the
    <image>, <rect>, and <svg> elements.
  - All the <filter-function> types from the Filter Effects
    Module Level 1 specification: blur(), brightness(),
    contrast(), drop-shadow(), grayscale(), hue-rotate(),
    invert(), opacity(), sepia(), saturate().
  - The filter property now supports chains of uri() filters or
    <filter-function> shortcuts.
  - Support CSS selectors for attribute matching, like
    rect[attr^="prefix"]
  + New APIs: See the HTML documentation for details.
- Drop -lang package: there are no translations available anymore.
* Sat Jun  5 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.50.7:
  + Two cairo-related bug fixes:
  - glgo#GNOME/librsvg#745: Fix mismatched cairo_save/restore
    when running in inside the Cairo test suite.
  - glgo#GNOME/librsvg#746: Possible cairo_save() without
    cairo_restore() in render_layer().
* Thu May 27 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.50.6:
  + Librsvg now requires at least Pango 1.44.
  + glgo#GNOME/librsvg#730: Incorrect text spacing when the
    transform is not 1:1. You can see this when a small font-size
    is scaled up due to a transform. It is less visible for a large
    font-size scaled down.
  + glgo#GNOME/librsvg#704: Fix circle/ellipse in paths when they
    are made out of a single Arc command.
* Fri Apr 30 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 2.50.5:
  + Images embedded as data: URLs didn't render if they had a MIME
    type with a charset parameter.
  + Don't allow number lists with unbounded lengths in tableValues
    attributes, for feComponentTransfer and feConvolveMatrix.
  + Negative rx/ry in rect element should be ignored.
* Fri Apr 23 2021 Federico Mena Quintero <federico@suse.com>
- Update to version 2.46.5 on SLE and Leap:
  + Update dependent crates that had security vulnerabilities:
    generic-array to 0.12.4 - RUSTSEC-2020-0146
    smallvec to 0.6.14      - RUSTSEC-2021-0003 - CVE-2021-25900
  + There are no changes to the library code.
  + Fix bash-isms in Makefile.am (Tin-Wei Lan).
  + Fix Visual Studio build (Chun-wei Fan).
- bsc#1183403 - CVE-2021-25900 - buffer overflow in the smallvec crate.
* Tue Apr 13 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to version 2.50.4:
  + Update dependent crates that had security vulnerabilities:
  - generic-array to 0.13.3 - RUSTSEC-2020-0146
  + Reduced stack usage
  + Add limit for too-large radiuses on the feMorphology filter
  + Properly ignore elements in an error state inside
    the "switch" element
* Thu Jan 28 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.50.3:
  + Compute correct bounds for objects with stroke-width=0.
  + Fix test suite on Rust 1.49.
* Fri Nov 20 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.50.2:
  + Fix dx/dy offsets in nested <tspan> elements.
* Mon Oct  5 2020 dimstar@opensuse.org
- Update to version 2.50.1:
  + SVG2: Support a chain of uri() filters in the "filter"
    property.
  + Support CSS selectors for attribute matching, like
    rect[attr^="prefix"].
  + Fixed the geometry_for_layer() APIs to not ignore the passed
    viewport.
  + Fixed CSS "import" so it allows only files from the same base
    directory.
  + The pkg-config files (*.pc) do not define the 'svgz_supported'
    and 'css_supported' variables anymore.  These variables were
    hardcoded to 'true' and unchanged since 2011.
  + The source repository no longer produces a
    librsvg-uninstalled.pc file.
* Fri Sep 11 2020 dimstar@opensuse.org
- Update to version 2.50.0:
  + Librsvg now consumes much less memory for large SVG files.
  + The 'font' shorthand in is now supported in CSS. Librsvg
    ignores the 'line-height' sub-property because it cannot be
    done easily with Pango, but everything else in 'font' should
    work now.
  + Many new features from SVG2:
  - radialGradient now supports the "fr" property from SVG2.
  - Support href attribute in addition to xlink:href per SVG2.
  - Ignore missing filter references per SVG2.
  - Support the mix-blend-mode property from SVG2 and the
    Compositing and Blending Level 1 specification, so layers can
    be composited with operators like multiply/screen/color-burn.
  - Support the paint-order property from SVG2, so one can pick
    the order in which a path's fill/stroke/markers are drawn.
  + Updated translations.
* Tue Jul 21 2020 Michel Normand <normand@linux.vnet.ibm.com>
- Add _constraints for PowerPC avoid "no space left on device" build error
* Sat Jul  4 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.48.8:
  + Compute 'bolder' and 'lighter' font-weight correctly.
* Thu Jun  4 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.48.7:
  + Fix failing tests.
* Tue Jun  2 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.48.6:
  + Fix build on big-endian machines.
* Fri May 29 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.48.5:
  + Support multiple fonts in the font-family property. Previously
    in font-family="Foo, Bar, Baz" only Foo would get used.
  + Catch overflow when rendering files with a huge viewBox.
  + Don't panic with an empty objectBoundingBox for a mask.
  + Fix introspection data for rsvg_handle_set_stylesheet.
  + Fixes to the librsvg_crate documentation.
  + Loading raster images for inclusion in an SVG and producing
    GdkPixbufs is now faster.
* Thu Apr 23 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.48.4:
  + Fix regression when rendering masks.
  + Fix panic when a big viewBox creates an invalid transform.
  + Fix invalid argument to g_log_structured_array().
* Fri Apr 10 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.48.3:
  + Librsvg now requires glib 2.50.0 or later.
  + rsvg-convert's --background-color option now accepts colors
    with transparency like #rrggbbaa, rgba(...), hsla(...); the
    transparency value was ignored before.
  + Fix arithmetic overflow when rendering to large GdkPixbufs.
  + Make librsvg build with Rust 1.39 again.
  + Don't require upcalls into C code for Debian powerpc.
- Add check section and run testsuite during build.
* Wed Apr  1 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.48.2:
  + Fix linking of the test suite against Harfbuzz.
* Sat Mar 28 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.48.1:
  + Fix baseline-shift for simple subscripts/superscripts and
    absolute offsets. This should fix a lot of Wikimedia images
    with formulas.
  + Support images with data: URLs that don't have a MIME-type.
    This fixes some Open Clip Art images generated by old versions
    of Adobe Illustrator.
  + Fix build of the test suite on Windows.
  + Support running the rsvg_internals tests on Windows.
* Sun Mar  8 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.48.0:
  + The following is a summary of changes between 2.46.x and
    2.48.0. For full details, please see the 2.47.x release notes
    below.
  + This release requires at least Rust 1.39.
  + New API, rsvg_handle_set_stylesheet(), to set a CSS stylesheet
    independent of the SVG document.
  + Support opacity in patterns.
  + Librsvg's XML parser now supports namespaces (xmlns), and is
    stricter than before about it. Files may fail to parse if there
    are attributes or elements with namespace prefixes (e.g.
    foo:bar instead of plain bar), but without a corresponding
    namespace declaration (e.g.
    xmlns:foo="http://example.com/foo").
    This may happen especially with incorrectly-written SVGs that
    use xlink:href or xi:include attributes without the
    corresponding namespace declarations. If you run into this,
    just add the following to your toplevel SVG element:
    <svg xmlns="http://www.w3.org/2000/svg"
    xmlns:xlink="http://www.w3.org/1999/xlink"
  xmlns:xi="http://www.w3.org/2001/XInclude">
    ^^^^^^^^^ these ones
  + Librsvg no longer depends on libcroco, and now does all CSS
    processing using Rust crates from Mozilla Servo. As a result,
    librsvg can now handle much more complex CSS selectors than
    before.
  + Link-time optimization (LTO) is disabled by default on release
    builds, as this increased build time too much. Downstream
    distributors may want to turn it back on in the toplevel
    Cargo.toml.
  + (CVE-2019-20446) - Librsvg now has limits on the number of
    loaded XML elements, and the number of referenced elements
    within an SVG document. This is to mitigate malicious SVGs
    which try to consume all memory, and those which try to consume
    an exponential amount of CPU time.
  + Many bugfixes; please see the 2.47.x release notes below.
- Changes from version 2.47.4:
  + Fix rsvg-convert's multipage PDF output when the zoom option is
    used.
  + Do not stop rendering if an <image> element references a
    nonexistent file. This fixes a number of Open Clipart cases.
  + Compute the font-size cascade correctly when there are "em"
    [#]and "ex" units involved.
  + Updated the man page for rsvg-convert.
* Wed Feb 12 2020 dimstar@opensuse.org
- Update to version 2.47.3:
  + New API, rsvg_handle_set_stylesheet(), to set a CSS
    stylesheet independent of the SVG document.
  + Support opacity in patterns.
  + Move away from the Cairo transform type to our own.
  + Update the gtk-rs version.
- Changes from version 2.47.2:
  + Handling of the "result", "in", "in2" attributes in filter
    primitives is slightly stricter now, and spec compliant.
  + Fix infinite loop when processing CSS sibling combinators.
  + feImage filters no longer clip their output to integer
    coordinates.
  + Documentation for the Rust crate.
  + Debug logs from RSVG_LOG=1 should now be more legible and
    contain better information on invalid CSS.
  + Remove link-time workarounds for Rust pre-1.35.
  + Unify internal error types to share the CSS code with
    gnome-shell.
  + Made handling of XML namespaces more spec-compliant.
  + Lots of refactoring to start moving away from Cairo internals.
- Changes from version 2.47.1:
  + Librsvg no longer depends on libcroco!  It now does all CSS
    processing using Rust crates from Mozilla Servo; these are also
    the crates that are in use in recent versions of Firefox.  As a
    result, librsvg can now handle much more complex CSS selectors
    than before.
- Drop pkgconfig(libcroco-0.6) BuildRequires: no longer needed.
* Mon Nov 25 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.46.4:
  + Panic when reading an invalid stylesheet URL in an XML
    processing instruction.
  + Consider specificity when applying CSS selector matches.
  + Provide an usage example in the librsvg crate docs.
- Drop patches fixed upstream:
  + 0001-croco.rs-Add-struct-definition-for-CRSimpleSel.patch
  + 0002-Compute-the-specificity-of-CSS-selectors.patch
  + 0003-525-Consider-specificity-when-applying-CSS-selector-.patch
* Wed Nov 13 2019 Yifan Jiang <yfjiang@suse.com>
- Add explicit conflicts between rsvg-convert and rsvg-view <=2.45.7.
* Tue Nov 12 2019 Frederic Crozat <fcrozat@suse.com>
- Fix incorrect obsoletes for rsvg-view.
* Thu Nov  7 2019 Fabian Vogt <fvogt@suse.com>
- Add patches to fix coloring of symbolic icons (glgo#GNOME/librsvg#525):
  * 0001-croco.rs-Add-struct-definition-for-CRSimpleSel.patch
  * 0002-Compute-the-specificity-of-CSS-selectors.patch
  * 0003-525-Consider-specificity-when-applying-CSS-selector-.patch
* Wed Nov  6 2019 Yifan Jiang <yfjiang@suse.com>
- Remove BuildRequires rust-std. The replacement rust-std-static
  is already required by rust.
* Wed Oct 23 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.46.3:
  + glgo#GNOME/librsvg#516: Fix inadvertent bump in the minimum
    Rust version required. The string_cache crate is now pinned to
    a version that still works on Rust 1.34.
  + glgo#GNOME/librsvg#521: Compute geometries correctly if there
    is a viewBox attribute.
  + glgo#GNOME/librsvg#308: Fix stack exhaustion with circular
    references in <use> elements.
  + Consistently use the LGPL 2.1 wherever it is mentioned.
- Drop COPYING, everything is covered by COPYING.LIB now.
* Mon Oct 14 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.46.2:
  + Patterns and gradients reused across more than one element will
    only get resolved once now; this should make things marginally
    faster for patterns or gradients with fallbacks.
  + glgo#GNOME/librsvg#515: Librsvg now has limits on the number of
    loaded XML elements, and the number of referenced elements
    within an SVG document. This is to mitigate malicious SVGs
    which try to consume all memory, and those which try to consume
    an exponential amount of CPU time.
* Mon Oct  7 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.46.1:
  + Fix empty patterns which reference a fallback pattern with
    children.
* Mon Sep  9 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.46.0:
  + All of librsvg.so is now implemented in Rust! That is, except
    for a very thin wrapper over the public API functions.
    Hopefully we can remove this wrapper when Cargo gets some more
    features around controlling the linking step. This release
    requires at least Rust 1.34.
  + Librsvg now comes with a Rust crate that can be used from Rust
    applications. See librsvg_crate/examples. This Rust API is
    designed to be idiomatic; if you want a Rust binding to the
    shared library instead, please use the "rsvg-rs" crate from
    crates.io.
  + The following API functions are new in the C library:
  - rsvg_handle_get_intrinsic_dimensions()
  - rsvg_handle_render_document()
  - rsvg_handle_render_layer()
  - rsvg_handle_render_element()
  - rsvg_handle_get_geometry_for_layer()
  - rsvg_handle_get_geometry_for_element()
  - Correspondingly, there is a new chapter in the documentation,
    called "Recommendations for Applications". These new APIs
    conform better with the web platform's idea of how SVG
    sizing/positioning should work. Applications should now find
    it easier to scale and render SVGs in a single call, instead
    of having to obtain image dimensions first.
  + A bunch of functions have been deprecated but are still
    available:
  - rsvg_handle_write()/close() are deprecated in favor of the
    stream functions. Unfortunately the write()/close() pair
    require buffering the entire document, in case it is a .svgz
    compressed file; the streaming functions do not have this
    problem.
  - Functions that return RsvgDimensionData and RsvgPositionData
    are deprecated, since they just use integers instead of
    floating point numbers. They are replaced with the
    _get_geometry_*() functions above.
  + The library is a lot more strict now in terms of detecting that
    the API functions are called in the correct order. For example,
    calling rsvg_handle_get_dimensions() before rsvg_handle_close()
    will now emit a critical warning.
  + Librsvg is gradually moving towards using code from Mozilla's
    Servo. We haven't quite gotten rid of libcroco and libxml2 yet,
    but this is in progress.
* Mon Sep  2 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.45.92:
  + Fix glgo#GNOME/librsvg#496: Ensure all lengths and angles parse
    as finite numbers.
  + Fix glgo#GNOME/librsvg#497: Don't panic on paths with
    all-invalid commands.
  + Fix glgo#GNOME/librsvg#500: Added additional SVG blend-modes
    for the feBlend filter primitive.
  + Some changes in the build structure to allow for faster builds.
* Mon Sep  2 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.45.90:
  + New API functions:
  - rsvg_handle_render_document().
  - rsvg_handle_render_layer().
  - rsvg_handle_render_element().
  - rsvg_handle_get_geometry_for_layer().
  - rsvg_handle_get_geometry_for_element().
  + CairoRenderer in the librsvg_crate has corresponding functions
    as well.
  + Fix builds with gettext ≥ 0.20.
  + If the C API is called out of order, downgrade hard panics to
    g_critical() to cope with incorrect/old applications that
    called rsvg_handle_get_dimensions() before
    rsvg_handle_close().
  + API reference documentation is much improved.
* Mon Sep  2 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.45.8:
  + This version requires at least Rust 1.34.
  + Fix build on Rust earlier than 1.36.
  + Update gtk-rs and dependent crates.
- Changes from version 2.45.7:
  + Don't panic if an SVG has character data outside the first
    element.
  + Don't panic when there's an xi:include fallback with no parent
    element.
  + Fix blurry semi-opaque objects when rendering with a scaled
    transformation.
  + Don't ignore the first x/y/dx/dy in text/tspan elements if
    there is more than one position specified.
  + In librsvg_crate, SvgHandle now has a ::has_element_with_id()
    method.
  + rsvg-convert now catches the case where the SVG has no
    dimensions.
  + This version no longer contains the rsvg-view program, so
    librsvg no longer depends on GTK.
  + The poly element no longer supports "verts" as an alias for the
    "points" attribute. The "verts" name was only used in SVG
    pre-1.0, and we had been cargo-culting that name ever since.
  + We now use more machinery from Mozilla Servo, in this case the
    markup5ever and rust-selectors crates. This is in line with
    gradually replacing libcroco with a Rust-only CSS machinery.
  + Lots and lots of refactoring and cleanups: use the rctree crate
    instead of our own tree representation; remove interior
    mutability in element structs; make the gradients and patterns
    code less repetitive.
  + Update some dependencies.
  + Fix static linking and Windows builds.
- Drop rsvg-view subpackage and pkgconfig(gtk+-3.0) BuildRequires
  and obsolete it from main library following upstream changes.
- Add new rsvg-convert subpackage for the convert tool previously
  packaged in rsvg-view.
* Mon Sep  2 2019 bjorn.lie@gmail.com
- Update to version 2.45.6:
  + Librsvg now requires Rust 1.30.0 or later.
  + Librsvg now requires Cairo 1.16.0 or later.
  + This version introduces librsvg_crate, an idiomatic Rust crate
    for using librsvg from Rust programs directly, without using
    GObject machinery. This API is subject to change, but you can
    start using it now in an experimental fashion.
  + All of the librsvg internals are now in Rust! The C code is
    just a thin wrapper over Rust functions.
  + The internals library has been converted to Rust 2018.
  + Within librsvg_crate, there is a new infrastructure for doing
    reftests in Rust, that does not depend on PNG reference files.
    See librsvg_crate/tests for details.
  + This release introduces the following new APIs:
  - rsvg_handle_get_intrinsic_dimensions(),
  - rsvg_handle_get_geometry_for_element().
  + Parsing of the "style" attribute, which has a plain list of CSS
    property declarations, is now done with rust-cssparser.
  + CSS selector matching should be marginally faster than before.
  + Fix Visual Studio builds.
  + Fix glgo#GNOME/librsvg#11: Respect the "direction" property for
    bidirectional text.
  + Fix glgo#GNOME/librsvg#295: Ensure the initial viewport fits
    into temporary surfaces for compositing.
  + Fix glgo#GNOME/librsvg#425: Don't fail parsing if the system's
    locale is broken.
  + Fix glgo#GNOME/librsvg#438, glgo#GNOME/librsvg#443: Don't
    create intermediate raster surfaces unless absolutely needed.
    This was causing blurred output for SVGs from Inkscape and
    Illustrator, since they include an "enable-background" property
    even when there are no filters in use.
  + Fix glgo#GNOME/librsvg#443: Fix blurry output when
    enable-background is used without filters.
  + Fix glgo#GNOME/librsvg#455: Fix rounding error on i386.
  + Check for Cairo errors when constructing paths.
* Mon Sep  2 2019 bjorn.lie@gmail.com
- Update to version 2.45.5:
  + At build time, you can now pass $CARGO and $RUSTC environment
    variables if you need to override the default Rust toolchain.
    Please see COMPILING.md for details.
  + Fix glgo#GNOME/librsvg#405: In the gdk-pixbuf loader, don't
    crash if the write() function doesn't receive a GError.
  + Fix glgo#GNOME/librsvg#268: Remove the comp-op property; it's
    not in SVG 1.1 nor SVG 2.
  + Fix glgo#GNOME/librsvg#415: register RsvgHandleFlags and the
    RsvgError enum values in a thread-safe fashion.
  + All of the library's non-GObject functionality is implemented
    in Rust now.
  + Update the cairo crate.
  + Clean up the loading code paths.
  + Updated compilation docs for Debian.
  + Updated parts of the reference documentation.
* Mon Sep  2 2019 bjorn.lie@gmail.com
- Update to version 2.45.4:
  + Fix glgo#GNOME/librsvg#402: Fix the library's soname.
* Mon Sep  2 2019 bjorn.lie@gmail.com
- Update to version 2.45.3:
  + Big news! All the real work in the library is now implemented
    in Rust. The public API is implemented in C, but most it calls
    immediately into the Rust code.
  + rsvg_handle_set_base_uri() now really assumes that it is passed
    a URI. Previously it would try to differentiate between real
    URIs, and absolute or relative file paths. If this breaks your
    code (i.e. you are passing a filename, not a URI), please tell
    us so we can restore the old behavior!
  + Fix glgo#GNOME/librsvg#395: Don't panic in feMorphology if it
    ends up with a negative scaling transformation.
  + Fix glgo#GNOME/librsvg#398: Detect circular references in
    gradients.
  + Match the Firefox/Chrome behavior on gradients and patterns
    with circular references for fallbacks.
  + Fixes for Rust 1.30 and below.
  + Lots and lots of refactoring.
- Changes from version 2.45.2:
  + rsvg_cleaup() is now deprecated. This was only meant to be
    called from code to be checked by Valgrind. Leak checkers may
    show reachable memory from libxml2; real memory leaks should
    still be reported, of course.
  + As an experimental change, librsvg no longer calls
    xmlInitParser() from libxml2. Please tell us if this causes
    problems for multithreaded programs.
  + Added g_warning()s to ensure the API is called in the correct
    sequence.
  + The text handling code has been completely refactored and
    simplified. This will allow us to implement the x/y/dx/dy
    properties for multiple glyphs in the future. Please report any
    problems you experience in text rendering.
  + Fix glgo#GNOME/librsvg#385: Don't crash if there is no
    rsvg_handle_write() before rsvg_handle_close().
  + Fix glgo#GNOME/librsvg#391: Avoid undefined behavior when
    casting opaque pointers.
  + Fix crash when a linear RGB filter is followed by an SRGB
    filter.
  + Fix glgo#GNOME/librsvg#393: Stack overflow when freeing
    thousands of sibling elements.
  + Fix positioning of adjacent <tspan> elements.
  + All the toplevel loading and drawing code is implemented in
    Rust now.
  + Pixbuf conversion code is in Rust now.
  + Cleanups in the code for XML processing, markers, attributes.
  + Many build/link fixes.
  + Cleanups in the code that calls libxml2.
- Changes from version 2.45.1:
  + New public API, rsvg_handle_get_geometry_sub(), to get the
    exact geometry of an element. The functions
    rsvg_handle_get_position_sub() and
    rsvg_handle_get_dimensions_sub() are deprecated now; these
    returned incomplete data with integer coordinates.
  + rsvg_handle_write() and rsvg_handle_close() are now deprecated
    in favor of the functions which use a GInputStream. The former
    need to buffer the entire SVG data first; the latter don't need
    buffering.
  + Librsvg no longer tries to load XML entities which reference
    external resources, either parameter or general entities,
    declared in the DTD. This never worked properly, and it is
    better to do so via the xi:include mechanism. Also, unparsed
    external entities with a notation are not really supported in
    SVG; it has its own <image> element and similar for that
    purpose. Only internal general entities are supported now, for
    example:
  - <!ENTITY foo "<some xml here>">.
  - <!ENTITY bar "some text here">.
  + Started support for localized error messages.
  + Ported to Rust: loading code, XML processing code, data: URL
    parsing.
  + Many code cleanups and refactorings.
  + Fix undefined behavior in casts.
  + Cairo/Rust API updates.
  + configure.ac cleanups.
- Add lang_package macro/subpackage, librsvg now have translations.
- Add a librsvg_sover define and set it to 2.
* Mon Sep  2 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.44.15:
  + Fix glgo#GNOME/librsvg#11: Respect the "direction" property for
    bidirectional text.
  + Fix glgo#GNOME/librsvg#462: Fix usage of std::f64::EPSILON for
    Rust 1.28.
  + Fix glgo#GNOME/librsvg#497: Don't panic on paths with
    all-invalid commands.
  + Fix glgo#GNOME/librsvg#496: Ensure all lengths and angles parse
    as finite numbers.
  + Fix glgo#GNOME/librsvg#426: Detect files vs. URIs in
    rsvg_handle_new_from_file() on Windows.
  + Fix a memory leak in the test suite.
* Tue May 14 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.44.14:
  + Fix glgo#GNOME/librsvg#425: Don't fail parsing if the system's
    locale is broken.
  + Fix glgo#GNOME/librsvg#438, glgo#GNOME/librsvg#443: Don't
    create intermediate raster surfaces unless absolutely needed.
    This was causing blurred output for SVGs from Inkscape and
    Illustrator, since they include an "enable-background" property
    even when there are no filters in use.
  + Fix glgo#GNOME/librsvg#443: Fix blurry output when
    enable-background is used without filters.
  + Fix glgo#GNOME/librsvg#455: Fix rounding error on i386.
  + Check for Cairo errors when constructing paths.
* Sat Feb 16 2019 bjorn.lie@gmail.com
- Update to version 2.44.13:
  + Updated compilation docs for Debian.
  + Fix glgo#GNOME/librsvg#415: Register RsvgHandleFlags and the
    RsvgError enum values in a thread-safe fashion.
* Mon Jan 21 2019 bjorn.lie@gmail.com
- Update to version 2.44.12:
  + At build time, you can now pass $CARGO and $RUSTC environment
    variables if you need to override the default Rust toolchain.
    Please see COMPILING.md for details.
  + Fix glgo#GNOME/librsvg#405: In the gdk-pixbuf loader, don't
    crash the write() function doesn't receive a GError.
  + Fix glgo#GNOME/librsvg#398: Detect circular references in
    gradients.
* Sat Dec 29 2018 bjorn.lie@gmail.com
- Update to version 2.44.11:
  + Fix crash when a linear RGB filter is followed by an SRGB
    filter.
  + Fix stack overflow when freeing thousands of sibling elements.
  + feMorphology was crashing with a negative scaling
    transformation.
  + Fix positioning of adjacent <tspan> elements.
* Tue Dec 11 2018 bjorn.lie@gmail.com
- Update to version 2.44.10:
  + Don't crash if there is no rsvg_handle_write() before
    rsvg_handle_close().
  + Avoid undefined behavior when casting opaque pointers.
  + Added g_warning()s to ensure the API is called in the correct
    sequence.
* Wed Nov 14 2018 bjorn.lie@gmail.com
- Update to version 2.44.9:
  + rsvg-convert was positioning extracted elements incorrectly
    when using the -w/-h options together with --export-id.
  + Mis-rendering in small arc segments.
  + Rendering of gradients for horizontal/vertical stroked lines
    with gradientUnits="userSpaceOnUse".
  + Fix a couple of memory leaks in the error paths of the
    GdkPixbuf loader.
* Thu Oct 25 2018 bjorn.lie@gmail.com
- Update to version 2.44.8:
  + Don't drop spaces around <tspan> elements.
  + rsvg-convert now uses pixel units for SVG output, instead of
    points.
  + Tweaks to have the test suite pass on i386 and non-x86_64
    platforms.
  + With RSVG_LOG=1, librsvg will now report when SVGs have
    references to nonexistent elements, to aid debugging (for
    example, in an xlink:href attribute).
  + Allow reference tests with a small difference to pass without
    breaking the build.
* Tue Oct  9 2018 bjorn.lie@gmail.com
- Update to version 2.44.7:
  + Correctly match the systemLanguage attribute with the user's
    locale.
  + Parse xml:lang correctly.
  + Don't modify the caller's cairo_t state during rendering.
  + Don't panic if we get a "data:" URI with empty data.
  + Don't panic on getting a very large "order" for
    feConvolveMatrix.
  + Bugs fixed: glgo#GNOME/librsvg#256, glgo#GNOME/librsvg#320,
    glgo#GNOME/librsvg#334, glgo#GNOME/librsvg#349,
    glgo#GNOME/librsvg#352.
* Fri Sep 28 2018 bjorn.lie@gmail.com
- Update to version 2.44.6:
  + Fix 32-bit builds.
- Changes from version 2.44.5:
  + Fix rsvg_handle_get_dimensions_sub() no longer panics if passed
    a nonexistent fragment identifier.
  + CSS processing code is now in Rust, although it still calls
    libcroco to do the parsing.
  + Bugs fixed: glgo#GNOME/librsvg#343, glgo#GNOME/librsvg#346,
    glgo#GNOME/librsvg#347, glgo#GNOME/librsvg#348,
    glgo#GNOME/librsvg#349.
* Tue Sep 25 2018 bjorn.lie@gmail.com
- Update to version 2.44.4:
  + Cleanups and refactoring.
  + Bugs fixed: glgo#GNOME/librsvg#341, glgo#GNOME/librsvg#342,
    glgo#GNOME/librsvg#344, glgo#GNOME/librsvg#345.
- Changes from version 2.44.3:
  + Fix building when srcdir != builddir.
  + Fixes from fuzz testing: don't panic when the feConvolveMatrix
    kernel is not set; fix upper bounds in filter pixel getters.
  + Updates to the CI infrastructure and the build documentation.
  + Bugs fixed: glgo#GNOME/librsvg#339, glgo#GNOME/librsvg#335,
    glgo#GNOME/librsvg#337, glgo#GNOME/librsvg#338,
    glgo#GNOME/librsvg#340.
* Wed Sep  5 2018 luc14n0@linuxmail.org
- Append Apache-2.0 and MIT licenses to main package's and
  librsvg-2-2 subpackage's License tags to comply with Rust crates,
  static linked against LibRSVG, licenses.
* Fri Aug 31 2018 bjorn.lie@gmail.com
- Update to version 2.44.2:
  + Don't leak all the elements at the toplevel
    (glgo#GNOME/librsvg#325).
  + Make masking work on big-endian (glgo#GNOME/librsvg#328).
  + Fix library ordering so -Wl,--as-needed works.
* Wed Aug 29 2018 bjorn.lie@gmail.com
- Update to version 2.44.1:
  + Don't panic if trying to render a non-empty SVG with no
    elements (glgo#GNOME/librsvg#324).
  + All the elements were being leaked at the toplevel
    (glgo#GNOME/librsvg#325).
* Thu Aug 23 2018 bjorn.lie@gmail.com
- Update to version 2.44.0:
  + Librsvg now has minimal logging for debugging by setting the
    RSVG_LOG environment variable. See CONTRIBUTING.md for details.
  + Speed improvements for Gaussian blur, SRGB conversions, and
    various filters.
  + Fix glgo#GNOME/librsvg#264: The letter-spacing property now
    supports "normal" in addition to lengths.
  + Fix glgo#GNOME/librsvg#318: The font-weight property was being
    parsed incorrectly.
  + Fix glgo#GNOME/librsvg#323: Don't use 100%% "forever" with
    malicious SVGs that cause an exponential number of elements to
    be instanced through the <use> element. We limit the number of
    <use> instances now.
  + Fix glgo#GNOME/librsvg#293: Don't panic when masking an empty
    group.
  + Fix glgo#GNOME/librsvg#319: Parse single font-family correctly.
  + Cleanups for the internal representation of elliptical arcs in
    paths.
* Thu Aug 23 2018 luc14n0@linuxmail.org
- Update to version 2.43.4:
  + This is an early release to test the effects of threading in
    librsvg.
  + The lighting and Gaussian blur filters are now parallelized
    with Rayon; they will use all available cores.
* Thu Aug 23 2018 luc14n0@linuxmail.org
- Update to version 2.43.3:
  + Tentative fix: Don't panic if rendering to a non-image Cairo
    surface (glgo#GNOME/librsvg#309).
  + Couple of optimizations.
* Thu Aug 23 2018 bjorn.lie@gmail.com
- Update to version 2.43.2:
  + All the filter effects have been ported to Rust.
  + We now require Rust 1.26.
  + We now include Rust debug information even in release builds,
    to make it easier to obtain stack traces.
  + Fix glgo#GNOME/librsvg#310: Respect DPI in the font-size
    property.
  + Fix: draw the circle/ellipse elements with the same orientation
    as the SVG 1.1 test suite; this is relevant for
    stroke-dasharray.
  + Refactoring of the drawing code and font sizes.
  + New filters in Rust: feConvolveMatrix, feColorMatrix,
    feMorphology, feDisplacementMap, feGaussianBlur,
    feDistantLight, feSpotLight, fePointLight, feTile.
  + Updated Rust dependencies.
* Thu Aug 23 2018 bjorn.lie@gmail.com
- Update to version 2.43.1:
  + Test fonts should now work with --enable-installed-tests
    (glgo#GNOME/librsvg#259).
  + Don't panic when trying to filter an empty group
    (glgo#GNOME/librsvg#277).
  + Don't panic if we try to clip an empty group
    (glgo#GNOME/librsvg#292).
  + Fix the feOffset filter's coordinate parsing.
  + Fix linearization of SRGB data in the feComposite filter.
  + Fix CSS cascading in filters.
  + Fix, don't render filters if they are in error.
  + Fixed a couple of memory leaks in the test suite.
  + Filters now support FillPaint and StrokePaint for input.
  + Filters now support the color-interpolation-filters property.
  + The feImage, feBlend, feComponentTransfer filters are now in
    Rust.
  + The feOffset filter now supports fractional offsets.
  + The drawing context code is now in Rust.
  + All the style property parsers have been moved to
    rust-cssparser.
* Thu Aug 23 2018 luc14n0@linuxmail.org
- Update to version 2.43.0:
  + Fixes:
  - feDistantLight and feSpotLight now work again
    (glgo#GNOME/librsvg#241).
  - feComposite is fixed not to overwrite the source image in
    some cases; this fixes drop shadows generated from Inkscape
    (glgo#GNOME/librsvg#282).
  + Rust implementation:
  - Text, tspan and tref elements;
  - Basic styling infrastructure;
  - Internals of the drawing infrastructure and bounding-box
    computation;
  - Element creation from the parsing stage;
  - Clipping and Masking.
  + The feComposite filter now operates in linear RGB space, for
    better spec compliance (glgo#GNOME/librsvg#275).
  + Filters now compute their bounds to floating-point values,
    instead of clipping them to integers.
  + Text rendering improvements.
* Thu Aug 23 2018 bjorn.lie@gmail.com
- Update to version 2.42.7:
  + Fix a denial-of-service condition from exponential explosion of
    rendered elements, through nested use of SVG "use" elements in
    malicious SVGs. This is similar to the XML "billion laughs
    attack" but for SVG instancing (glgo#GNOME/librsvg#323).
* Tue Aug  7 2018 bjorn.lie@gmail.com
- Update to version 2.42.6:
  + Fix drop-shadows generated from Inkscape; we were overwriting
    a surface inadvertently (glgo#GNOME/librsvg#282).
  + Fix confusion between feSpotLight and feDistantLight
    (glgo#GNOME/librsvg#241).
  + Don't panic if we try to clip with an empty region
    (glgo#GNOME/librsvg#292).
  + Fix out-of-tree builds and tests.
  + Compilation can now use a RUST_TARGET variable to override the
    host triplet when cross-compiling. See COMPILING.md for
    details.
* Sat Jun  2 2018 bjorn.lie@gmail.com
- Update to version 2.42.5:
  + Don't render filter primitives that have invalid attributes.
    This was causing a crash in feColorMatrix
    (glgo#GNOME/librsvg#266).
  + rsvg_handle_render_cairo() will now refuse to render if the
    cairo_t passed to it is in an error state. Fixes a panic in the
    cairo-dock program (glgo#GNOME/librsvg#276).
  + The test suite now writes test artifacts to tests/output
    instead of /tmp (glgo#GNOME/librsvg#206).
* Mon May  7 2018 luc14n0@linuxmail.org
- Update to version 2.42.4:
  + Fixes:
  - Elements with systemLanguage attributes without variants now
    work better.
  - Possible crash on invalid gradient references.
  - Negative values are catched in stroke-dasharray properties
    instead of leaving the cairo_t in an error state
    (glgo#GNOME/librsvg#227).
  - Empty transform attribute now correctly yields an identity
    transform (glgo#GNOME/librsvg#228).
  + Make robust against patterns and gradients with no children.
  + Lots of code cleanups and refactorings.
  + Code moved to Rust: low-level path and PangoLayout drawing,
    "switch" element.
* Mon Mar  5 2018 dimstar@opensuse.org
- Update to version 2.42.3:
  + glgo#GNOME/librsvg#205: The configure script now checks for
    Rust 1.20.0. Previously this minimum requirement was not
    well-defined.
  + glgo#GNOME/librsvg#204: New feature: If an SVG has an <a> link
    element, we now generate the corresponding link when
    outputting to a Cairo PDF surface.  If you use rsvg-convert(1)
    with PDF output, <a> links in the SVG will work in the PDF.
  + glgo#GNOME/librsvg#108: New feature: support font-size:larger
    and font-size:smaller relative sizes.
  + New feature: rsvg-convert now supports SOURCE_DATE_EPOCH to
    generate reproducible output for PDFs.
  + glgo#GNOME/librsvg#197: New requirement: We now require
    Freetype2 2.9.0, which fixes font rendering bugs. The test
    reference PNGs have been regenerated with this version.
  + glgo#GNOME/librsvg#91: Fix rendering of masks and clips when
    the initial transformation has a translation component.
  + glgo#GNOME/librsvg#112: Fix: apply style attributes for all SVG
    elements, not just for the toplevel one.
  + glgo#GNOME/librsvg#161: Fix the marker angle for the last
    vertex of closed paths.
  + glgo#GNOME/librsvg#198: Fix: Make rsvg_pixbuf_from_file() and
    its derived functions work again.  Now we have tests for the
    whole public API.
  + glgo#GNOME/librsvg#143: Minor optimizations for Gaussian blurs.
  + glgo#GNOME/librsvg#201: Minor speedups in the code to parse SVG
    attributes.
  + glgo#GNOME/librsvg#178: Fix some tests that failed on 32-bit
    machines.
  + In addtion to --enable-debug/--disable-debug to control the
    Rust compilation, now you can use an environment variable
    LIBRSVG_DEBUG=yes / LIBRSVG_DEBUG=no if you wish.
  + Code moved to Rust: SVG paint servers, SVG attribute parsing.
  + We now use a Cargo workspace internally, to move more things to
    Rust.
- Add pkgconfig(freetype2) BuildRequires: New dependency.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Fri Feb  2 2018 bjorn.lie@gmail.com
- Update to version 2.42.2:
  + Don't crash when feConvolveMatrix doesn't specify orderx/ordery
    attributes (glgo#librsvg#193).
  + Parse stroke-dasharray property correctly. This code is in Rust
    now; yay! (glgo#librsvg#136).
  + Don't render markers if they are zero-sized, per the spec.
  + Performance: eliminate a bunch of string copies during parsing.
  + Update rust-cssparser to 0.23.
* Tue Jan 23 2018 bjorn.lie@gmail.com
- Update to version 2.42.1:
  + Parse the transform attribute in a faster/simpler way. We now
    use rust-cssparser instead of lalrpop.  This is especially
    noticeable on SVGs with lots of "transform" attributes
    (glgo#librsvg#182).
  + Don't crash when setting a gradient on a zero-sized object
    (glgo#librsvg#187).
  + Inherit attributes in the <svg> element properly
    (glgo#librsvg#181).
  + rsvg-convert - fix error reporting when reading from stdin
    (glgo#librsvg#160).
  + Fix detection of image type in "data:" URIs when they don't
    specify a MIME type (glgo#librsvg#152).
  + More stringent parsing of path data; better tests
    (glgo#librsvg#133).
  + Fix typos and links in the .md files.
* Tue Jan  9 2018 zaitor@opensuse.org
- Update to version 2.42.0:
  + Fix a memory leak in rsvg_handle_new_from_file().
  + Optimize the xml:space normalization function.
  + Fix a runtime warning in the feMergeNode code
    (glgo#GNOME/librsvg#179).
  + Clarify documentation about the rsvg_*_sub() APIs
    (glgo#GNOME/librsvg#175).
  + Stylistic fixes from cargo-clippy.
  + Port the Pango glue code to Rust.
  + New ARCHITECTURE.md with a description of librsvg's internals.
- Clean up spec, use autosetup macro.
* Wed Dec 27 2017 luc14n0@linuxmail.org
- Update to version 2.41.2:
  + Bug fixes:
  - Mis-use of libxml2 (bgo#787895).
  - Allow masks and clips to reuse a node being drawn
    (bgo#761175).
  + Fixes:
  - xml:space normalization, per the spec.
  - Bugs from Coverity runs.
  - Loading files one byte at a time.
  - Some memory leaks.
  + Don't access the file system when deciding whether to load a
    remote file with a UNC path for a paint server (i.e. don't try
    to load it at all).
  + Add:
  - Support for cross-compilation of the Rust code.
  - Verbosity to Cargo.
  + Markers now have the correct default size per the SVG spec.
  + Don't render elements that establish a viewport if their
    viewBox size is 0, per the spec.
  + SVG elements ported to Rust: image, clipPath, mask, character
    data in elements.
  + Reference documentation now have an overview of the library and
    is DocBook 5.1.
  + Expanded the test suite.
  + Lots of internal refactoring.
- Changes from version 2.41.0:
  + The big news is that parts of librsvg are now implemented in
    the Rust programming language, instead of C. The public API
    remains identical. Rust should provide us with memory safety
    and nicer built-in abstractions for the code, as well as an
    easier way to do unit tests.
  + Added an "--enable-debug" option to configure.ac - this will
    tell the Rust compiler to generate debugging code, instead of
    working in release mode. Note that you must still pass CFLAGS
    by hand by the regular means for the C code.
  + The path data parser now handles boolean values in Arc elements
    correctly.
  + Radial gradients now adjust the focus point correctly to be
    within the gradient's radius.
  + Stroke width normalization is now conformant to the spec.
  + Viewport-relative length normalization is now conformant to the
    spec.
  + Added some of the official SVG 1.1 test files to our test
    suite. Fixed a little bunch of conformance bugs.
  + Code that has been converted to Rust:  marker orientations and
    rendering, path data parser, path building, length
    normalization, gradient inheritance, bounding boxes with affine
    transformations.
  + Added tests/README.md with instructions on how to run the test
    suite and update it.
  + rsvg-test can now skip files or directories that start with
    "ignore".
  + Fixes:
  - feImage filters when they reference SVG nodes.
  - eComponentTransferFunction when there are duplicated feFuncX.
    elements.
  - Conformance bugs in gradient inheritance.
  - A few minor issues.
  + Fixed bugs: bgo#763386, bgo#603550, bgo#776297, bgo#761871,
    bgo#686953.
- Changes from version 2.41.1:
  + The feConvolveMatrix filter primitive now is working.
  + Pattern specifications can now have a fallback color, per the
    spec - https://www.w3.org/TR/SVG/painting.html#SpecifyingPaint
  + Tests now use a very basic form of reproducible font rendering.
    This means that "make check" should pass even if you have a
    custom Fontconfig setup.
  - A few cases of uninitialized struct fields.
  + Per the spec, we now don't render elements which have invalid
    attributes.
  + Don't crash in filters when one of them yields an invalid
    surface for an intermediate result.
  + Added a bunch of new test cases for the new features and the
    code converted to Rust.
  + cairo-rs 0.2.0 and lalrpop 0.13.1 are now required.
  + Fixes:
  - Recursive fallbacks in gradients.
  - Division by zero in feTile filter when the input surface is
    empty.
  - parsing of "azimuth", "elevation", "limitingConeAngle" for
    filter effects.
  + Fixed bugs: bgo#621088, bgo#587721, bgo#776932, bgo#777155,
    bgo#776297, bgo#777834, bgo#634324, bgo#783835, bgo#779489,
    bgo#782098, bgo#777833, bgo#786372, bgo#634514, bgo#785276,
    bgo#778666.
- Update Url to https://wiki.gnome.org/Projects/LibRsvg: current
  LibRsvg project's web page.
- Add BuildRequires for the following new dependencies that
  upstream's rust implementation brought: cargo, rust and rust-std.
- Add pkgconfig(cairo-png) BuildRequires: it was already being
  pulled with pkgconfig(cairo) and used, since they live in the
  same devel package.
- Add gio-unix-2.0 and gthread-2.0 pkgconfig BuildRequires: they
  were already being pulled with pkgconfig(glib-2.0) and used,
  since they all live in glib2-devel package.
- Adopt the use of %%make_build rather than raw make command and
  switch %%makeinstall by the preferred %%make_install macros,
  following the best practices.
- Remove obsoleted %%clean section since RPM does this job now and
  replace old macro for number of jobs control with %%make_build
  following best practices.
- Change rsvg-thumbnailer subpackage group to
  Productivity/Graphics/Other as this is a better fit for it.
- Export -Wl,-z,noexecstack LDFLAG to avoid executable-stack
  issues. It's only a temporary flag until upstream give feedback
  (glgo#GNOME/librsvg#177).
* Wed Dec 27 2017 jengelh@inai.de
- Fix RPM groups, drop redundant %%clean section,
  update summaries.
* Sat Dec 16 2017 luc14n0@linuxmail.org
- Update to version 2.40.20:
  + Allow masks and clips to reuse a node being drawn (bgo#761175).
  + Don't access the file system when deciding whether to load a
    remote file with a UNC path for a paint server (i.e. don't try
    to load it at all).
  + Fix generation of Vala bindings when compiling in read-only
    source directories.
* Thu Oct  5 2017 dimstar@opensuse.org
- Update to version 2.40.19:
  + Fix the <switch> element; it wasn't working at all.
  + Fix loading when rsvg_handle_write() is called one byte at a
    time.
  + Backported the test suite machinery from the master branch.
  + Bugs fixed: bgo#587721, bgo#621088, bgo#634324, bgo#634514,
    bgo#777155, bgo#777833, bgo#782098, bgo#785276, bgo#786372,
    bgo#787895.
- Add pkgconfig(fontconfig) and pkgconfig(pangoft2) BuildRequires:
  new dependencies verified by configure.
* Thu Jul 20 2017 zaitor@opensuse.org
- Update to version 2.40.18 (boo#1049607, CVE-2017-11464):
  + Fix division-by-zero in the Gaussian blur code (bgo#783835,
    boo#1049607, CVE-2017-11464).
  + Fix other cases of division-by-zero on fuzzed SVG files.
  + Don't crash on invalid transformation matrices.
  + Support Visual Studio 2017; generate .pc files for Meson on
    Windows.
* Mon Apr 10 2017 zaitor@opensuse.org
- Update to version 2.40.17:
  + bgo#778666: Use our own thumbnailer specification file, so
    gnome-desktop-thumbnailer can generate thumbnails outside of
    the calling process.
  + Removed some redundant code.
  + Windows build fixes.
- Split out new sub-package rsvg-thumbnailer (noarch).
* Thu Jun  9 2016 zaitor@opensuse.org
- Update to version 2.40.16:
  + Support for building the introspection files under MSVC.
  + Make the zooming options in rsvg-convert(1) work again for
    scaling the resulting image (bgo#760262).
  + Wikipedia generates equations as SVGs and renders them, but
    uses fill="currentColor". Since we don't let caller specify a
    starting state for CSS, we need to start with opaque black as
    the default current color (bgo#764808).
  + Added documentation for how to replace the deprecated
    rsvg_handle_set_size_callback().
- Drop librsvg-Fix-rsvg-convert.patch: Fixed upstream.
* Mon Apr 18 2016 zaitor@opensuse.org
- Add librsvg-Fix-rsvg-convert.patch: Actually scale the image if
  required, regression fix from upstream git (bgo#760262).
* Fri Apr 15 2016 mgorse@suse.com
- Update to GNOME 3.20  Fate#318572
* Sat Apr  2 2016 zaitor@opensuse.org
- Update to version 2.40.15:
  + Librsvg now uses the Contributor Covenant Code of Conduct,
    version 1.4, to which all contributors and maintainers are
    expected to abide. Please see the code_of_conduct.md file for
    details.
  + Fixed builds on Visual Studio pre-2012.
  + Fixed bgo#759084: Don't crash when filters don't actually
    exist.
  + Updated our autogen.sh to use modern autotools.
  + Fixed bgo#761728: Memory leak in the PrimitiveComponentTransfer
    filter.
* Fri Jan  8 2016 zaitor@opensuse.org
- Update to version 2.40.13:
  + Fixed the Windows build.
  + Added basic support for the "baseline-shift" attribute in text
    objects (bgo#340047).
  + Fixed some duplicate logic when rendering paths (bgo#749415).
  + Rewrote the markers engine (bgo#685906, bgo#760180).
* Wed Dec  2 2015 zaitor@opensuse.org
- Update to version 2.40.12:
  + Refactoring of the test harness to use Glib's gtest
    infrastructure, instead of using home-grown machinery.  Tests
    can simply be put as SVG files in the tests/subdirectories; it
    is not necessary to list them explicitly in some text file.
  + Gzipped SVGs now work if read from streams.
  + References to objects/filters/URIs/etc. are now handled lazily.
    Also, there is a general-purpose cycle detector so malformed
    SVGs don't cause infinite loops.
  + Removed parsing of Adobe blend modes; they were not
    implemented, anyway.
  + Bugs fixed: bgo#700911, bgo#630732, bgo#677068.
* Thu Oct  8 2015 zaitor@opensuse.org
- Update to version 2.40.11:
  + Add project files for building on Visual Studio (bgo#753555).
  + Added an "--export-id" option to rsvg-convert(1). This lets you
    select a single object to export, for example, to pick out a
    group from a multi-part drawing.  Note that this is mostly
    useful for PNG output right now; for SVG output we don't
    preserve many attributes which could be useful in the extracted
    version.  Doing this properly requires an internal "output to
    SVG" backend instead of just telling Cairo to render to SVG.
* Sun Aug  9 2015 zaitor@opensuse.org
- Update to version 2.40.10:
  + bgo#748608: Memory leak when Gaussian-blurring.
  + bgo#739329: Font-family attributes with singly-quoted names
    were not handled correctly, yielding incorrect fonts.
  + bgo#476507: Path start/end markers didn't have the correct
    angle if the path was a curve with coincident control points.
  + bgo#688689: Support font-style="normal" within a non-normal
    styled text block.
  + Fixed builddir != srcdir.
  + Remove a bunch of deprecated GTK+ calls.
* Fri May 15 2015 dimstar@opensuse.org
- Remove reference to gtk2-engine-svg from baselibs.conf: this
  subpackage hasn't been built since Oct 22 2013.
* Fri Mar 27 2015 zaitor@opensuse.org
- Update to version 2.40.9:
  + bgo#738367: V/v/H/h commands in path elements were not working.
  + bgo#605875: Gaussian-blurred objects were sometimes missing.
  + bgo#710163: Use _wfullpath() on Windows when canonicalizing
    filenames.
* Fri Feb 27 2015 zaitor@opensuse.org
- Update to version 2.40.8 (boo#916784):
  + Bugs fixed from fuzz testing: bgo#744688 - possible double
    g_free() when processing stroke-dasharray.
  + Optimize rendering of polylines, lines, rectangles, circles,
    and ellipses.  These should be marginally faster, marginally
    more precise, and should put less pressure on the memory
    allocator.
* Mon Feb 16 2015 dimstar@opensuse.org
- Update to version 2.40.7:
  + Fixed unfiled bug from fuzz testing, where the convolution
    filter had an integer multiplication overflow.
  + Fix build of rsvg-convert on Windows.
  + Fix a bunch of compiler warnings.
  + Bugs fixed from fuzz testing: bgo#703102, bgo#738050,
    bgo#738169, bgo#744270, bgo#744299.
* Wed Dec  3 2014 zaitor@opensuse.org
- Update to version 2.40.6:
  + MinGW build fixes.
  + Fix path data number parsing.
  + Fix build with newer libtool.
* Mon Oct 13 2014 dimstar@opensuse.org
- Update to version 2.40.5:
  + bgo#736825: handle: Call close() after write() even on write
    error.
  + bgo#735836: rsvg-convert: Fix argument processing.
* Sun Sep 14 2014 asterios.dramis@gmail.com
- Update to version 2.40.4:
  + rsvg-convert: Handle gzip compressed input (bgo#735836).
* Sat Aug 23 2014 dimstar@opensuse.org
- BuildIgnore adwaita-icon-theme: Avoid cycle: we do not require
  the adwaita-icon-theme to be present. libgtk-3.0 requires this
  for end users.
* Mon Aug 18 2014 dimstar@opensuse.org
- Update to version 2.40.3:
  + Bugs fixed: bgo#731182, bgo#710310, bgo#721354.
* Tue Mar 18 2014 dimstar@opensuse.org
- Update to version 2.40.2:
  + Bugs fixed: bgo#710163, bgo#719552.
* Tue Nov 19 2013 dimstar@opensuse.org
- Update to version 2.40.1:
  + Build fixes.
  + Crash fixes.
* Tue Oct 22 2013 zaitor@opensuse.org
- Update to version 2.40.0:
  + Add support for parsing rgba() colours and improve colour
    parsing.
  + Rsvg-filter: Fix memory leak.
  + Remove support for GTK+2 along with the old theme engine.
  + Require at least version 3.2 of GTK+.
  + Remove support for old versions of gdk-pixbuf.
  + Add eps support to rsvg-convert.
- Drop pkgconfig(gtk+-2.0) BuildRequires, no longer needed nor
  supported.
- Remove gtk2-engine-svg subpackage, no longer built.
* Sat Sep 14 2013 dimstar@opensuse.org
- Update to version 2.39.0:
  + Don't load resources from the net (bgo#691708, CVE-2013-1881).
- The restrictiveness is being correctly addressed by GTK+ 3.9.11;
  we prefer to have the more secure librsvg variant in 13.1.
* Wed Aug 21 2013 zaitor@opensuse.org
- Downgrade to version 2.37.0:
  + We can not use librsvg version 2.39.0 as it is too restrictive
    (bgo#706428).
* Fri Aug 16 2013 dimstar@opensuse.org
- Update to version 2.39.0:
  + Don't load resources from the net (bgo#691708, CVE-2013-1881).
* Thu Jan 10 2013 dimstar@opensuse.org
- Update to version 2.37.0:
  + Bump pango requirement to 1.32.6.
  + Mark pixbuf loader as threadsafe.
* Tue Oct 16 2012 dimstar@opensuse.org
- Update to version 2.36.4:
  + Build fixes.
* Sun Sep  2 2012 dimstar@opensuse.org
- Update to version 2.36.3:
  + Build fixes.
* Sun Aug 19 2012 dimstar@opensuse.org
- Update to version 2.36.2:
  + GObject introspection fixes (bgo#677674).
  + Added Vala bindings (bgo#677676).
  + Deprecate including headers apart from rsvg.h directly.
  + Build fixes (bgo#677661).
- Add vala BuildRequires: needed for the new vala bindings.
- Pass --enable-vala to configure.
* Tue Apr 17 2012 vuntz@opensuse.org
- Update to version 2.36.1:
  + Bugs fixed: bgo#672725, bgo#672791, bgo#672885, bgo#673748.
- Add pkgconfig(gmodule-2.0) BuildRequire: new dependency upstream.
* Mon Mar 26 2012 vuntz@opensuse.org
- Update to version 2.36.0:
  + Bugs fixed: bgo#669563, bgo#672414, bgo#672792, bgo#672725.
- Drop librsvg-gdk-pixbuf-query-loaders-64.patch: fixed upstream,
  by checking for both gdk-pixbuf-query-loaders-64 and
  gdk-pixbuf-query-loaders.
- Remove automake BuildRequires: it was only needed for above
  patch.
- Remove hack in %%install to not install data files for an old
  non-working GTK+ 3 theme: fixed upstream.
* Sat Feb 25 2012 vuntz@opensuse.org
- Remove librsvg:/usr/bin/rsvg Provides from rsvg-view: the
  /usr/bin/rsvg tool doesn't exist anymore.
* Wed Feb  8 2012 vuntz@opensuse.org
- Really build introspection support:
  + Pass --enable-introspection to configure.
  + Add typelib-1_0-Rsvg-2_0 subpackage.
  + Add typelib-1_0-Rsvg-2_0 Requires to devel subpackage.
- Stop passing non-existing --with-svgz option to configure.
- Change group of librsvg-2-2 from Development/Libraries/C and C++
  to System/Libraries.
* Tue Feb  7 2012 vuntz@opensuse.org
- Update to version 2.35.2:
  + Bug fixes.
- Remove xz BuildRequires now that it comes for free in the build
  system.
- Add gobject-introspection-devel BuildRequires to build
  introspection support: somehow, we never did that earlier.
- Drop env-paths.diff: the script that was patched got dropped.
- Remove definition of gtk3-engine-svg subpackage: the gtk+ 3 theme
  engine got removed.
- Remove build_gtk3_support macro and always build with GTK+ 3
  support now that it's all fine.
- Add hack in %%install to not install data files for an old
  non-working GTK+ 3 theme.
* Tue Dec 20 2011 vuntz@opensuse.org
- Update to version 2.35.1:
  + Support basic vertical writing (bgo#664533).
  + Bugs fixed: bgo#664684, bgo#665905, bgo#665824.
  + Several misc. code changes.
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
- Add explicit pkgconfig(pangocairo) BuildRequires: it was missing
  before.
- Fix license of subpackages: all the code is LGPL-2.0+, except
  some tests that are not shipped in subpackages. The overall
  license of the source package is "LGPL-2.0+ ; GPL-2.0+".
* Thu Dec  1 2011 coolo@suse.com
- Add automake BuildRequires to avoid implicit dependency.
* Mon Nov 14 2011 dimstar@opensuse.org
- Update to version 2.35.0:
  + Update libxml2 dependency to 2.7.0
  + Make GIO and libcroco hard requirements
  + Use attributes for deprecations instead of defines
  + Many memory leaks plugged
  + Bugs fixed: bgo#621636, bgo#630112, bgo#624820, bgo#624835,
    bgo#581108, bgo#614157, bgo#630733, bgo#473862, bgo#590788,
    bgo#626559, bgo#663049, bgo#663049.
- Drop no longer needed pkgconfig() BuildRequires following
  upstream changes: fontconfig, freetype2,, libgsf-1, pangoft2.
- Rebase librsvg-gdk-pixbuf-query-loaders-64.patch.
* Tue Sep  6 2011 vuntz@opensuse.org
- Update to version 2.34.1:
  + Store node type separately in RsvgNode (bgo#658014,
    CVE-2011-3146)
  + cairo: reduce cost of measuring bounding boxes
  + Use "const" instead G_CONST_RETURN (bgo#652213)
  + Call xmlFreeParserCtxt after using the context (bgo#655472)
* Mon Apr  4 2011 fcrozat@novell.com
- Update to version 2.34.0:
  + Allow building rsvg-view with gtk 3
  + Bugs fixed: bgo#629392, bgo#626802, bgo#641586, bgo#640336,
    bgo#635214, fdo#30071, bgo#629412, bgo#630714.
* Mon Nov 15 2010 dimstar@opensuse.org
- Update to version 2.32.1:
  + fdo#30071: Make sure the surfaces own their pixels
  + bgo#630714: Remove stray comma from enum
  + bgo#629412: Dist testcase input file.
* Mon Oct 11 2010 vuntz@opensuse.org
- Add a Provides for librsvg to librsvg-2-2 in baselibs.conf, like
  in the .spec file.
- Add missing Requires for gdk-pixbuf-query-loaders to
  gdk-pixbuf-loader-rsvg in baselibs.conf.
- Add gtk2-engine-svg to baselibs.conf, since we want theme engines
  to be bi-arch too.
* Mon Oct  4 2010 vuntz@opensuse.org
- Fix librsvg-2-2 Provides/Obsoletes to work: they were using
  %%{name} instead of %%{version} for the version. Fix bnc#642068.
* Mon Sep 27 2010 vuntz@opensuse.org
- Update to version 2.32.0:
  + Disable gtk3 build since it's currently broken.
- Drop librsvg-gdk-pixbuf-render-gtk3.patch and
  librsvg-gdkkeysym-compat.patch: those patches are only needed for
  gtk3 support, and the gtk3 support will be enabled upstream when
  they will get fixed.
- Add build_gtk3_support define in .spec, to easily add back the
  gtk3 support to the package. Right now, this means we lose the
  gtk3-engine-svg subpackage.
* Sat Sep 18 2010 vuntz@opensuse.org
- Add librsvg-gdkkeysym-compat.patch to fix build with recent
  versions of GTK+.
* Thu Sep  9 2010 vuntz@opensuse.org
- Add librsvg-gdk-pixbuf-render-gtk3.patch to fix build with
  GTK+ 3: the pixbuf renderer was using API that got removed. The
  patch is correct, but suboptimal, so it's still sitting in
  bugzilla. However, since we're not using this GTK+ engine by
  default, it's okay to use it.
* Fri Jul 23 2010 vuntz@opensuse.org
- Make devel package Require librsvg-2-2 instead of librsvg.
* Wed Jul 21 2010 vuntz@opensuse.org
- Update to version 2.31.0:
  + bgo#337979: text size not rendered correctly
  + bgo#545158: Segfault or bad rendering when displaying a SVG
    file
  + bgo#614556: Background pixbuf in filter process should not be
    created if it's not needed.
  + bgo#616018: cairo-freetype font rendering code should be
    removed.
  + bgo#620130: Decode base64 inplace
  + bgo#620238: crashes rending a trivial file
  + bgo#620592: Use correct free func
  + bgo#620649: Simplify code by using g_clear_error
  + bgo#620693: presentation attributes in svg element are ignored
  + bgo#620822: Build fails with make -jx"
  + bgo#621699: make librsvg gio friendly
  + bgo#622790: use standalone gdk-pixbuf
  + bgo#623383: crash on rsvg-gobject.c:141, in instance_dispose
    function
- Add librsvg-gdk-pixbuf-query-loaders-64.patch to fix the build on
  x86_64, since gdk-pixbuf-query-loaders is renamed to
  gdk-pixbuf-query-loaders-64 there.
- Remove coreutils PreReq.
- Change gtk2-devel, libcroco-devel, libgsf-devel BuildRequires to
  pkgconfig() BuildRequires: cairo, fontconfig, freetype2,
  gdk-pixbuf-2.0, glib-2.0, gio-2.0, gtk+-2.0, libcroco-0.6,
  libgsf-1, libxml-2.0, pangoft2.
- Add pkgconfig(gtk+-3.0) BuildRequires.
- Remove the cairo-devel, libcroco-devel, glib2-devel, gtk2-devel,
  libgsf-devel Requires in devel package: pkgconfig() Requires will
  automatically get added now.
- Version the Provides/Obsoletes of librsvg2 and librsvg2-devel in
  librsvg-2-2 and librsvg-devel to avoid rpmlint warning.
- Split the gdk-pixbuf loader in a gdk-pixbuf-loader-rsvg
  subpackage (that gets installed automatically when gdk-pixbuf is
  installed thanks to a Supplements).
- Create a librsvg-2-2 subpackage that provides/obsoletes librsvg
  (since the main package is empty), and follow the shared library
  policy.
- Create gtk2-engine-svg and gtk3-engine-svg subpackages,
  containing the svg-based theme engines.
* Sat May  8 2010 dimstar@opensuse.org
- Update to version 2.26.3:
  + bgo#143300: wrong bounding box when importing SVG
  + bgo#403274: text in thumbnail too large
  + bgo#404976: Unicode decomposed chars are not rendered well
  + bgo#524690: text alignment incorrect with text-anchor:end
  + bgo#545158: Segfault or bad rendering when displaying a SVG
    file
  + bgo#563933: corrupted rendering of a card in 'Paris' aisleriot
    card theme
  + bgo#564527: rsvg_handle_get_dimensions_sub weird behaviour
  + bgo#564544: shape-rendering crispEdges property is antialiasing
    line elements
  + bgo#566433: Could not read a valid svg file (inkspace read it)
  + bgo#579286: This SVG-File crashes nautilus/rsvg-view
  + bgo#581491: rsvg rendering is broken when encounters a 0px
    styled <text>
  + bgo#589612: EOG error when loading a large SVG
  + bgo#592207: Object cannot be rendered with more than 1 CSS {}
    rule
  + bgo#597873: glib-mkenums cannot be invoked when GLib is
    uninstalled.
  + bgo#597988: incorrect pkgconfig file let's others fail to
    detect librsvg
  + bgo#598151: Incorrect rendering of svg file
  + bgo#608575: Hang on particular SVG input
  + bgo#612951: SVG not rendered if header contains width or height
    in percentage
  + bgo#614123: librsvg builds tests even if tests are not run
  + bgo#614555: should remove unused rsvg_filter_adobe_blend
    function
  + bgo#614566: Needless G_OBJECT macro should be removed.
  + bgo#614606: !important is not respected
  + bgo#614643: does not handle comma separated CSS selector
    without libcroco
  + bgo#614703: Need tests for get_dimensions.
  + bgo#614704: css style doesn't override presentation attributes
  + bgo#614730: Rendering not disabled for 0 sized objects
  + bgo#614866: tests for CSS handling
  + bgo#615490: rsvg-view should scale image size by default if the
    image has huge canvas.
  + bgo#615699: rsvg-view should show zoom ratio.
  + bgo#615701: class directive in svg element is not used at all
  + bgo#615715: .class#id type selector is not supported.
  + bgo#616187: rsvg-view crashes when open a svg image
  + bgo#616835: Fix linking with pedantic linkers
  + bgo#617163: !important directive support without libcroco.
* Tue Mar 30 2010 vuntz@opensuse.org
- Update to version 2.26.2:
  + Enable silent build by default
  + Use GDK_DRAWABLE() instead of non-existing GTK_DRAWABLE()
  + Fix compiler warnings
- Update to version 2.26.1:
  + Remove some deprecated gtk+/gdk functions and bump gtk+
    requirement
  + Fix linking with pedantic linkers
  + Make librsvg compile with -DGSEAL_ENABLED
  + Drop mozilla plugin
* Fri Mar 26 2010 vuntz@opensuse.org
- Stop building the mozilla plugin: browsers now do support svg, so
  it's useless.
- Remove librsvg-plugin subpackage.
- Drop librsvg-xulrunner191.patch and remove
  mozilla-xulrunner-devel BuildRequires.
* Sat Dec 19 2009 jengelh@medozas.de
- Add baselibs.conf as a source
* Wed Sep  2 2009 dimstar@opensuse.org
- Add librsvg-xulrunner191.patch to enable building against
  xulrunner 1.9.1.
* Mon Mar 16 2009 vuntz@novell.com
- Update to version 2.26.0:
  + Command-line tools can't handle UTF-8 encoded filenames
    (bgo#557036)
  + Background color setting feature in rsvg_convert program
    (bgo#556969)
  + Gdmgreeter segfault due to libxml2 API/ABI change (bgo#549087)
  + Plug mem leak (bgo#552919)
  + Stop crash due to recursive references (bgo#518640)
  + Don't use deprecated glib symbols
  + Stray Makefile variables (bgo#558039)
  + -I flag-ordering problem breaks build if system already has lib
    installed (bgo#558040)
  + Add rsvg_handle_get_dimensions_sub() (bgo#555682)
  + Add version check macro (bgo#564226)
  + Indicate in the .pc file whether svgz and css support is
    available (bgo#564616)
  + Add function to check whether the SVG document contains an
    element by ID (bgo#567070)
  + Do not allocate RsvgState in rsvg_new_image() (bgo#557082)
  + Plug mem leak (bgo#562546)
  + Clean up GLib and GTK+ includes (bgo#563789)
  + librsvg can not render text-decoration=underline text
    (bgo#566365)
  + Don't use deprecated gdk_pixbuf_unref (bgo#570938)
  + "const static" should be "static const" (bgo#570656)
  + Better error messages (bgo#567307)
  + Crashes on some architectures because of wrong zero check on
    doubles (bgo#565371)
  + Filter nodes are leaked (bgo#475851)
  + Plug mem leaks (bgo#444444)
  + Fails to parse SVG with parameter entities (bgo#567311)
* Sat Feb 28 2009 vuntz@novell.com
- Remove BuildRequires: docbook-toys, gtk-doc
- Remove Requires of devel package: libbz2-devel, libart_lgpl-devel
- Remove --with-html-dir configure flag that breaks the doc
  install, and non-existing --without-gimp flag.
- Move rsvg binary to librsvg package.
- Remove autoreconf call.
- Use makeinstall.
* Sat Jan 31 2009 vuntz@novell.com
- Remove unneeded BuildRequires: docbook-toys,
  libgnomeprintui-devel, update-desktop-files, xmlcharent
- Remove Requires for the devel package: popt-devel, rsvg-view
- Do not have rsvg-view supplement gnome-session: we don't need it
  by default on GNOME
- Remove checks for old versions of openSUSE
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Tue Nov 25 2008 sbrabec@suse.cz
- Supplement gtk2-32bit/gtk2-64bit in baselibs.conf (bnc#354164).
* Fri Oct  3 2008 mboman@suse.de
- Update to version 2.22.3:
  + Make librsvg buildable on windows without freetype dependency
  + Fix build and tests
  + Fix the handling of the stroke-dashoffset property
  + Bad rendering for some wacko SVG path data
  + Fix some arcs not being well drawn in SVG path
  + Fix various crashes
  + Set license field of GdkPixBufFormat in the SVG loader
  + Migrate use of GMemChunk to GSlice
  + If an ID is not found, return an error and/or do not render whole SVG
* Tue Jul 22 2008 coolo@suse.de
- switch to xulrunner190 to avoid java dependency for gnome
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Fri Mar 14 2008 maw@suse.de
- Update to version 2.22.2:
  + Bug fixed: bgo#520261.
* Tue Mar  4 2008 maw@suse.de
- Update to version 2.22.1:
  + Text rendering fixes, especially for non-ASCII text
  + Better cairo integratino
  + Use GIO
  + Use GtkPrint.
* Fri Feb 15 2008 dmueller@suse.de
- split off rsvg-view (20kb), removes 6.2MB from the KDE CD
* Tue Jan 29 2008 maw@suse.de
- Remove libtool archives.
* Tue Jan 29 2008 rodrigo@suse.de
- Update to version 2.20.0:
  * Fixed memory leaks and segfaults
* Mon Sep 10 2007 maw@suse.de
- Update to version 2.18.2
- librsvg-64bit-warning.patch was necessary due to a typo in
  2.18.1; that typo was removed in 2.18.2, and therefore the patch
  has been too.
* Thu Aug 30 2007 maw@suse.de
- Update to version 2.18.1:
  + Basic support for SVG 1.1's text-rendering and shape-rendering
    properties (bugzilla.gnome.org #464599)
- M-x replace-string RET %%run_ldconfig RET /sbin/ldconfig RET
- Add librsvg-64bit-warning.patch.
* Thu Aug  2 2007 mauro@suse.de
- Updated to 2.18.0
- Bugfixes for #412682, #418823, #401115, #444462, #452823, #448327,
  [#444462], #444443, #435129, #409030, #375649, #421697, #421710,
  [#427031], #407230, #402246, #402107, #393297, #388545.
* Mon Jul 16 2007 dmueller@suse.de
- move deprecated rsvg command into -devel subpackage.
  scripts that break should use rsvg-convert instead
* Sat Mar 17 2007 aj@suse.de
- Require python for rsvg command (#242072).
* Mon Feb 19 2007 maw@suse.de
- Update to version 2.16.1
- Remove librsvg-xulrunner.patch which is now upstream.
* Sun Feb 18 2007 aj@suse.de
- Cleanup BuildRequires.
* Tue Feb 13 2007 sbrabec@suse.cz
- Do not build unusable static libraries (#238552#c17).
* Tue Jan  9 2007 sbrabec@suse.cz
- Patched to build plugin with xulrunner.
* Tue Jan  9 2007 maw@suse.de
- Fix a typo
- (Temporarily) remove the plugin subpackage.
* Tue Jan  9 2007 sbrabec@suse.cz
- Prefix changed to /usr.
- Spec file cleanup.
* Thu Dec 28 2006 jhargadon@suse.de
- removed unused libtool archives (#223654)
* Fri Oct 13 2006 danw@suse.de
- Remove dead patch
* Fri Sep 15 2006 sbrabec@suse.cz
- Removed mDNSResponder-lib from Requires - should be implicit.
* Thu Sep 14 2006 jhargadon@suse.de
- update to version 2.16.0
- librsvg.def: Make export symbols work on OSX
- rsvg-private.h: Some preparation work for color normalization
- Bug 344116: Committed patch from Kouhei Sutou that makes librsvg
  use Pango-Cairo instead of PangoFT2+rendering text as a path.
- rsvg-base.c (rsvg_handle_write_impl): Have libxml2 replace entities
  for us. This fixes a bug where style definitions don't get properly
  expanded, but causes a (2.15.x-only feature) regression when importing
  external ENTITIES.
* Wed Aug 23 2006 jhargadon@suse.de
- update to version 2.15.90
- Bug 348329 make gnome-print dependency optional
- Don't leak PangoFt2 fonts (bug 344235)
- Document _render_sub better (bug 346964)
* Mon Aug 14 2006 ro@suse.de
- use wildcard in filelist for gtk2 version
* Fri Jul 28 2006 ro@suse.de
- include rsvg.devhelp2 in filelist
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Oct 13 2005 gekker@suse.de
- Update to version 2.12.7
- Fix use of uninitialized variables
* Fri Sep 16 2005 rodrigo@suse.de
- Update to version 2.12.0
* Mon Sep  5 2005 gekker@suse.de
- Update to version 2.11.1 (GNOME 2.12)
* Fri Aug 12 2005 sbrabec@suse.cz
- Fixed devel requirements (#104295).
* Wed Jun  1 2005 sbrabec@suse.cz
- Fixed devel requirements.
* Sun Feb  6 2005 gekker@suse.de
- Update to version 2.9.5
* Wed Jan 19 2005 ro@suse.de
- fixed filelist
* Wed Dec 22 2004 gekker@suse.de
- Update to version 2.8.1
- Make *.svg and *.devhelp install
* Tue May  4 2004 sbrabec@suse.cz
- Updated to version 2.6.5 (GNOME 2.6).
* Mon Mar 15 2004 sbrabec@suse.cz
- FHS 2.3 fix (mandir, infodir, #35821).
* Wed Mar 10 2004 sbrabec@suse.cz
- Fixed %%postun.
- Fixed doc build.
* Sat Jan 10 2004 adrian@suse.de
- add %%defattr and %%run_ldconfig
* Mon Oct 20 2003 sbrabec@suse.cz
- Do not build SVG plug-in (moved to gimp2 package).
* Wed Oct  8 2003 sbrabec@suse.cz
- Updated to version 2.4.0 (GNOME 2.4).
* Tue Aug 26 2003 sbrabec@suse.cz
- Added Provides/Obsoletes for old name.
* Tue Aug 19 2003 sbrabec@suse.cz
- Package renamed (librsvg2 -> librsvg).
* Sun Jul 27 2003 hhetter@suse.de
- fix build
* Mon Jul 14 2003 sbrabec@suse.cz
- GNOME prefix change to /opt/gnome.
* Wed Jul  9 2003 sbrabec@suse.cz
- Branched gimp2-svg (to simplify dependences).
* Wed Jun 25 2003 sbrabec@suse.cz
- Updated to version 2.2.5.
- Updated neededforbuild.
- Turned on GIMP plugin, libgsf and SVGZ support.
* Wed Feb 12 2003 hhetter@suse.de
- install the rsvg loader at the default gdk-pixbuf-loader
  module location
- updated to version 2.2.3 to critical bugs with SVG themes
* Thu Jan 30 2003 hhetter@suse.de
- force running of SuSEconfig.gtk to register the
  librsvg gdk-pixbuf loader
* Tue Jan 28 2003 hhetter@suse.de
- updated to version 2.2.1
- update filelist
- include gdk-pixbuf loaders
* Mon Nov 11 2002 ro@suse.de
- changed neededforbuild <xf86 xdevel> to <x-devel-packages>
* Tue Oct 22 2002 hhetter@suse.de
- remove wrong docdir
- use correct kde datadir
* Fri Sep 27 2002 ro@suse.de
- Added alsa alsa-devel to neededforbuild (esound)
* Mon Aug 12 2002 ro@suse.de
- removed control-center from neededforbuild
* Tue Jul 23 2002 hhetter@suse.de
- updated to version 2.0.1
  * trashcan rendering problems fixed
* Tue Jul 23 2002 hhetter@suse.de
- updated to version 2.0.0
* Wed May 15 2002 ro@suse.de
- use libdir
* Mon Apr 15 2002 hhetter@suse.de
- update to version 1.1.6 [gnome desktop beta3]
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Thu Jan 24 2002 hhetter@suse.de
- initial SuSE package for GNOME 2.0 platform
